﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using GwApiNET;
using GwApiNET.ResponseObjects;

namespace GwApiNETTest
{

    public static class TestData
    {
        #region Expected Values

        public static EntryDictionary<int, MapEntry> MapEntriesExpected = new EntryDictionary<int, MapEntry>
            {
                {
                    80, new MapEntry
                        {
                            Id = 80,
                            MapName = "A Society Function",
                            MinLevel = 8,
                            MaxLevel = 8,
                            DefaultFloor = 1,
                            Floors = new[] {1, 2},
                            RegionId = 8,
                            RegionName = "Steamspur Mountains",
                            ContinentId = 1,
                            ContinentName = "Tyria",
                            MapRectangle = new List<int[]>
                                {
                                    new[] {-21504, -21504},
                                    new[] {24576, 21504}
                                },
                            ContinentRectangle = new List<int[]>
                                {
                                    new[]
                                        {
                                            10240,
                                            9856
                                        },
                                    new[]
                                        {
                                            12160,
                                            11648
                                        },
                                },

                        }
                },
                {
                    423, new MapEntry
                        {
                            Id = 423,
                            MapName = "The Championship Fight",
                            MinLevel = 19,
                            MaxLevel = 19,
                            DefaultFloor = 1,
                            Floors = new[] {1, 2},
                            RegionId = 8,
                            RegionName = "Steamspur Mountains",
                            ContinentId = 1,
                            ContinentName = "Tyria",
                            MapRectangle = new List<int[]>
                                {
                                    new[] {-27648, -18432},
                                    new[] {27648, 21504}
                                },
                            ContinentRectangle = new List<int[]>
                                {
                                    new[]
                                        {
                                            19456,
                                            13312
                                        },
                                    new[]
                                        {
                                            21760,
                                            14976
                                        },
                                }

                        }
                }

            };

        public static EntryDictionary<int, ObjectiveNameEntry> ObjectiveNamesExpected = new EntryDictionary
            <int, ObjectiveNameEntry>
            {
                {30,new ObjectiveNameEntry {Id = 30, Name = "Tower"}},
                {9, new ObjectiveNameEntry {Id = 9, Name = "Castle"}},
                {7, new ObjectiveNameEntry {Id = 7, Name = "Blue Mine"}},
                {13, new ObjectiveNameEntry {Id = 13, Name = "Tower"}},
            };

        public static MapFloorEntry MapFloorEntriesExpected = new MapFloorEntry
            {
                TextureDimensions = new[] {16384, 16384},
                ClampedView = new List<int[]>()
                    {
                        new[] {7168, 7294},
                        new[] {8190, 8190},
                    },
                Regions = new Dictionary<int, RegionEntry>()
                    {
                        {
                            6, new RegionEntry()
                                {
                                    Id = 6,
                                    Name = "Player vs. Player",
                                    LabelCoord = new[] {2560, 5344},
                                    Maps = new SerializableDictionary<int, RegionMap>()
                                        {
                                            {
                                                900, new RegionMap()
                                                    {
                                                        Id = 900,
                                                        Name = "Skyhammer",
                                                        MinLevel = 0,
                                                        MaxLevel = 0,
                                                        DefaultFloor = 27,
                                                        MapRectangle = new List<int[]>()
                                                            {
                                                                new[] {-12288, -6144},
                                                                new[] {12288, 9216}
                                                            },
                                                        ContinentRectangle = new List<int[]>()
                                                            {
                                                                new[] {7168, 7422},
                                                                new[] {8192, 8062}
                                                            },
                                                        PointsOfInterest = new EntryCollection<PointOfInterest>()
                                                            {
                                                                new PointOfInterest()
                                                                    {
                                                                        Id = 1797,
                                                                        Name = "Blue Team Rally Point",
                                                                        Type = PointOfInterestType.Waypoint,
                                                                        Floor = 9,
                                                                        Coordinates = new double[] {7595.29, 7882.28}
                                                                    },
                                                                new PointOfInterest()
                                                                    {
                                                                        Id = 1798,
                                                                        Name = "Red Team Rally Point",
                                                                        Type = PointOfInterestType.Waypoint,
                                                                        Floor = 9,
                                                                        Coordinates = new double[] {7595.8, 7586.38}
                                                                    }

                                                            },
                                                        Tasks = new EntryCollection<TaskEntry>(),
                                                        SkillChallenges = new EntryCollection<SkillChallengeEntry>(),
                                                        Sectors = new EntryCollection<SectorEntry>()
                                                            {
                                                                new SectorEntry()
                                                                    {
                                                                        Id = 1110,
                                                                        Name = "",
                                                                        Level = 0,
                                                                        Coordinates = new double[] {7662.14,7744.6}
                                                                    }
                                                            }
                                                    }
                                            }
                                        }
                                }
                        }
                    }
            };

        public static EntryDictionary<int, ContinentEntry> ContinentEntriesExpected = new EntryDictionary
            <int, ContinentEntry>
            {
                {
                    1,
                    new ContinentEntry
                        {
                            Id = 1,
                            Name = "Tyria",
                            Dimension = new[] {32768, 32768},
                            MinZoom = 0,
                            MaxZoom = 7,
                            Floors = new[]
                                {
                                    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
                                    11, 12, 13, 14, 15, 16, 17, 18, 19,
                                    30, -2, -3, -4, -5, -6, -7, -8,
                                    -10, -11, -15, -16, -17, 20, 21,
                                    22, 23, 24, 25, 26, 27, 34,
                                },
                        }
                },
                {
                    2,
                    new ContinentEntry
                        {
                            Id = 2,
                            Name = "Mists",
                            Dimension = new[] {16384, 16384},
                            MinZoom = 0,
                            MaxZoom = 6,
                            Floors = new[]
                                {
                                    1, 3, 5, 6, 7, 8, 9, 10, 13, 14, 18,
                                    19, 21, 22, 23, 24, 25, 26, -27, -28,
                                    -29, -30, -31, -32, -33, 27,
                                },
                        }
                },
            };

        public static EntryDictionary<int, ColorEntry> ColorEntriesExpected = new EntryDictionary<int, ColorEntry>
            {
                {
                    668,
                    new ColorEntry
                        {
                            Id = 668,
                            Name = "Pink Ice",
                            Cloth = new ColorEntry.ColorItemEntry
                                {
                                    Brightness = 50,
                                    Contrast = 1.36719,
                                    Hue = 8,
                                    Saturation = 0.351563,
                                    Lightness = 1.36719,
                                    RGB = Color.FromArgb(216, 172, 164),
                                },
                            Leather = new ColorEntry.ColorItemEntry
                                {
                                    Brightness = 47,
                                    Contrast = 1.71875,
                                    Hue = 8,
                                    Saturation = 0.234375,
                                    Lightness = 1.71875,
                                    RGB = Color.FromArgb(207, 170, 163),
                                },
                            Metal = new ColorEntry.ColorItemEntry
                                {
                                    Brightness = 47,
                                    Contrast = 1.64063,
                                    Hue = 8,
                                    Saturation = 0.429688,
                                    Lightness = 1.48438,
                                    RGB = Color.FromArgb(211, 145, 134),
                                },
                            BaseRGB = Color.FromArgb(128, 26, 26),
                        }
                },
                {
                    657,
                    new ColorEntry
                        {
                            Id = 657,
                            Name = "Pastel Pink",
                            Cloth = new ColorEntry.ColorItemEntry
                                {
                                    Brightness = 52,
                                    Contrast = 1.40625,
                                    Hue = 8,
                                    Saturation = 0.585938,
                                    Lightness = 1.40625,
                                    RGB = Color.FromArgb(247, 170, 157),
                                },
                            Leather = new ColorEntry.ColorItemEntry
                                {
                                    Brightness = 52,
                                    Contrast = 1.40625,
                                    Hue = 8,
                                    Saturation = 0.546875,
                                    Lightness = 1.40625,
                                    RGB = Color.FromArgb(243, 172, 159),
                                },
                            Metal = new ColorEntry.ColorItemEntry
                                {
                                    Brightness = 47,
                                    Contrast = 1.5625,
                                    Hue = 8,
                                    Saturation = 0.546875,
                                    Lightness = 1.40625,
                                    RGB = Color.FromArgb(220, 141, 126),
                                },
                            BaseRGB = Color.FromArgb(128, 26, 26),
                        }
                },
                {
                    1233,
                    new ColorEntry
                        {
                            Id = 1233,
                            Name = "Shiver Sky",
                            Cloth = new ColorEntry.ColorItemEntry
                                {
                                    Brightness = 42,
                                    Contrast = 1.99219,
                                    Hue = 200,
                                    Saturation = 0.234375,
                                    Lightness = 1.5625,
                                    RGB = Color.FromArgb(89, 125, 143),
                                },
                            Leather = new ColorEntry.ColorItemEntry
                                {
                                    Brightness = 42,
                                    Contrast = 1.83594,
                                    Hue = 200,
                                    Saturation = 0.195313,
                                    Lightness = 1.5625,
                                    RGB = Color.FromArgb(113, 140, 154),
                                },
                            Metal = new ColorEntry.ColorItemEntry
                                {
                                    Brightness = 42,
                                    Contrast = 1.99219,
                                    Hue = 200,
                                    Saturation = 0.195313,
                                    Lightness = 1.83594,
                                    RGB = Color.FromArgb(115, 145, 160),
                                },
                            BaseRGB = Color.FromArgb(128, 26, 26),
                        }
                }
            };

        public static EntryDictionary<Guid, EventDetailsEntry> EventDetailsExpected = new EntryDictionary
            <Guid, EventDetailsEntry>
            {
                {
                    new Guid("EED8A79F-B374-4AE6-BA6F-B7B98D9D7142"),
                    new EventDetailsEntry
                        {
                            EventId = new Guid("EED8A79F-B374-4AE6-BA6F-B7B98D9D7142"),
                            Name = "Defeat the renegade charr.",
                            Level = 42,
                            MapId = 20,
                            Flags = new EventDetailsEntry.FlagType[0],
                            Location = new EventLocation
                                {
                                    Type = EventLocationType.Sphere,
                                    Center = new[] {-9463.6, -40310.2, -785.799,},
                                    Radius = 2500,
                                    Rotation = 0,
                                },
                        }
                },
                {
                    new Guid("41D585D0-37E6-46FB-B88B-FC1FF0AF318A"),

                    new EventDetailsEntry
                        {
                            EventId = new Guid("41D585D0-37E6-46FB-B88B-FC1FF0AF318A"),
                            Name = "Defeat the crazed ettin and its raptor pack.",
                            Level = 38,
                            MapId = 17,
                            Flags = new EventDetailsEntry.FlagType[0],
                            Location = new EventLocation
                                {
                                    Type = EventLocationType.Cylinder,
                                    Center = new[] {-10750.1, 21801.1, -2196.29,},
                                    Height = 1243.27,
                                    Radius = 1333.37,
                                    Rotation = 0,
                                },
                        }
                },
                {
                    new Guid("EB8D67FD-8371-4E21-A934-805C025D0AF4"),

                    new EventDetailsEntry
                        {
                            EventId = new Guid("EB8D67FD-8371-4E21-A934-805C025D0AF4"),
                            Name = "Use Ezoola's tool to collect ice cores needed to summon elementals for the assault.",
                            Level = 66,
                            MapId = 22,
                            Flags = new EventDetailsEntry.FlagType[0],
                            Location = new EventLocation
                                {
                                    Type = EventLocationType.Poly,
                                    Center = new[] {-21760.5, 25836.4, -2266.5,},
                                    ZRange = new[] {-4598, 65,},
                                    Points = new List<double[]>
                                        {
                                            new[] {-25752.2, 19492},
                                            new[] {-27360.7, 22336.3},
                                            new[] {-26119.7, 26445.1},
                                            new[] {-22926.1, 30119.1},
                                            new[] {-18234.1, 32204.7},
                                            new[] {-15935.1, 31763.8},
                                            new[] {-16831.1, 23742.3},
                                            new[] {-20925.2, 20588.2},
                                        },
                                    Rotation = 0,
                                },
                        }
                },
            };

        public static List<MatchDetailsEntry> MatchDetailsExpected = new List<MatchDetailsEntry>
            {
                new MatchDetailsEntry
                    {
                        Id = "1-4",
                        Scores = new[] {113310, 223227, 125579,},
                        Maps = new EntryCollection<MatchMap>
                            {
                                new MatchMap
                                    {
                                        Type = MatchMapType.RedHome,
                                        Scores = new[] {63352, 26332, 10840,},
                                        Objectives = new EntryCollection<MatchObjective>
                                            {
                                                new MatchObjective {Id = 32, Owner = OwnerColor.Red,},
                                                new MatchObjective
                                                    {
                                                        Id = 35,
                                                        Owner = OwnerColor.Green,
                                                        OwnerGuildId = new Guid("FD63FC7C-1AA9-40E9-B73B-162FCF5F9E94"),
                                                    },
                                                new MatchObjective
                                                    {
                                                        Id = 37,
                                                        Owner = OwnerColor.Red,
                                                        OwnerGuildId = new Guid("1332E4E3-0668-4DB3-ADAB-A45FF9FCA25A"),
                                                    },
                                                new MatchObjective {Id = 53, Owner = OwnerColor.Green,},
                                            },
                                    },
                                new MatchMap
                                    {
                                        Type = MatchMapType.GreenHome,
                                        Scores = new[] {12512, 24363, 61933,},
                                        Objectives = new EntryCollection<MatchObjective>
                                            {
                                                new MatchObjective {Id = 41, Owner = OwnerColor.Green,},
                                                new MatchObjective {Id = 42, Owner = OwnerColor.Green,},
                                                new MatchObjective
                                                    {
                                                        Id = 46,
                                                        Owner = OwnerColor.Green,
                                                        OwnerGuildId = new Guid("3C36A8AF-FC20-46F5-BE14-C68567C2E7A5"),
                                                    },
                                                new MatchObjective {Id = 57, Owner = OwnerColor.Green,},
                                            },
                                    },
                            },
                    },
            };

        public static EntryDictionary<string, MatchEntry> MatchEntriesExpected = new EntryDictionary<string, MatchEntry>
            {
                {
                    "2-7",
                    new MatchEntry
                        {
                            Id = "2-7",
                            RedWorldId = 2014,
                            BlueWorldId = 2102,
                            GreenWorldId = 2105,
                            StartTime = DateTime.Parse("2013-07-19T18:00:00"),
                            EndTime = DateTime.Parse("2013-07-26T18:00:00"),
                        }
                },
                {
                    "2-9",
                    new MatchEntry
                        {
                            Id = "2-9",
                            RedWorldId = 2011,
                            BlueWorldId = 2001,
                            GreenWorldId = 2004,
                            StartTime = DateTime.Parse("2013-07-19T18:00:00"),
                            EndTime = DateTime.Parse("2013-07-26T18:00:00"),
                        }
                },
                {
                    "1-2",
                    new MatchEntry
                        {
                            Id = "1-2",
                            RedWorldId = 1017,
                            BlueWorldId = 1009,
                            GreenWorldId = 1008,
                            StartTime = DateTime.Parse("2013-07-20T01:00:00"),
                            EndTime = DateTime.Parse("2013-07-27T01:00:00"),
                        }
                },
                {
                    "1-8",
                    new MatchEntry
                        {
                            Id = "1-8",
                            RedWorldId = 1006,
                            GreenWorldId = 1024,
                            BlueWorldId = 1001,
                            StartTime = DateTime.Parse("2013-07-20T01:00:00"),
                            EndTime = DateTime.Parse("2013-07-27T01:00:00"),
                        }
                },
            };

        public static EntryDictionary<int, MapNameEntry> MapNameEntriesExpected = new EntryDictionary<int, MapNameEntry>
            {
                {50, new MapNameEntry {Id = 50, Name = "Lion's Arch"}},
                {873, new MapNameEntry {Id = 873, Name = "Southsun Cove"}},
                {30, new MapNameEntry {Id = 30, Name = "Frostgorge Sound"}},
            };

        public static EntryDictionary<int, WorldNameEntry> WorldNameEntriesExpected = new EntryDictionary
            <int, WorldNameEntry>
            {
                {1017, new WorldNameEntry {Id = 1017, Name = "Tarnished Coast"}},
                {2011, new WorldNameEntry {Id = 2011, Name = "Vabbi"}},
                {2001, new WorldNameEntry {Id = 2001, Name = "Fissure of Woe"}},
            };

        public static EntryDictionary<Guid, EventNameEntry> EventNameEntriesExpected = new EntryDictionary
            <Guid, EventNameEntry>
            {
                {
                    new Guid("BAD81BA0-60CF-4F3B-A341-57C426085D48"),
                    new EventNameEntry
                        {
                            Id = new Guid("BAD81BA0-60CF-4F3B-A341-57C426085D48"),
                            Name = "Moa Racer Meep",
                        }
                },
                {
                    new Guid("330BE72A-5254-4036-ACB6-7AEED05A521C"),
                    new EventNameEntry
                        {
                            Id = new Guid("330BE72A-5254-4036-ACB6-7AEED05A521C"),
                            Name = "Moa Racer Motti",
                        }
                },
                {
                    new Guid("B13EA882-065D-470A-8A9D-10A395373C68"),
                    new EventNameEntry
                        {
                            Id = new Guid("B13EA882-065D-470A-8A9D-10A395373C68"),
                            Name = "Patrol with the Lionguard to secure the road.",
                        }
                },
            };
        public static IdList RecipeIdListExpected = new IdList
            {
        #region Recipe IDList
                1275,
                3147,
                959,
                3219,
                3721,
                3491,
                4914,
                805,
                4979,
                4467,
                3479,
                1346,
                4219,
                842,
                2404,
                742,
                5252,
                2928,
                6202,
                1633,
                572,
                7238,
                1752,
                5004,
                5616,
                3670,
                6031,
                5790,
                1559,
                6983,
                4927,
                6522,
                6478,
                5743,
                6886,
                2829,
                1193,
                5642,
                4542,
                3024,
                7679,
                2655,
                950,
                3406,
                4202,
                907,
                7237,
                1415,
                5191,
                4585,
                5623,
                3374,
                816,
                7377,
                4965,
                1735,
                1200,
                6775,
                224,
                2085,
                403,
                1014,
                5253,
                1620,
                7276,
                3851,
                5528,
                1937,
                2047,
                2159,
                1274,
                4864,
                5773,
                6099,
                3066,
                1075,
                3745,
                3029,
                6162,
                4192,
                4040,
                2565,
                6071,
                2104,
                340,
                1577,
                3150,
                4834,
                4779,
                5098,
                7339,
                3373,
                6296,
                304,
                2570,
                6842,
                2545,
                956,
                6534,
                4384,
                2533,
                3674,
                7150,
                1021,
                2574,
                466,
                762,
                642,
                3085,
                3174,
                844,
                5403,
                5682,
                4762,
                919,
                4193,
                1060,
                1283,
                4171,
                1712,
                3475,
                6902,
                1130,
                2026,
                3489,
                4167,
                6159,
                6934,
                1728,
                6161,
                3841,
                1702,
                5349,
                3473,
                2392,
                319,
                4076,
                3797,
                444,
                1192,
                6078,
                5606,
                1499,
                6198,
                5532,
                4757,
                1814,
                3505,
                7266,
                4319,
                2651,
                553,
                2779,
                6295,
                6303,
                6616,
                3009,
                4052,
                4005,
                4408,
                3215,
                2698,
                3125,
                3439,
                3996,
                965,
                3312,
                4987,
                1812,
                4440,
                1332,
                6835,
                5426,
                5113,
                2164,
                264,
                6891,
                4333,
                127,
                6263,
                5200,
                7084,
                1594,
                5529,
                4948,
                3681,
                5917,
                718,
                3191,
                2730,
                5985,
                6575,
                7148,
                1560,
                4978,
                1181,
                1,
                7400,
                7799,
                565,
                2116,
                5531,
                5300,
                4250,
                2087,
                860,
                2147,
                101,
                1112,
                6398,
                1242,
                6763,
                1324,
                6000,
                2405,
                5992,
                7177,
                6423,
                5484,
                1747,
                6972,
                3041,
                3919,
                342,
                1657,
                5671,
                6732,
                7247,
                5152,
                7227,
                6974,
                4980,
                5630,
                6155,
                3027,
                7032,
                6742,
                2356,
                4744,
                1947,
                6428,
                1832,
                1387,
                3741,
                4943,
                6179,
                1369,
                6510,
                1841,
                5424,
                6715,
                7705,
                4441,
                3391,
                4334,
                4471,
                193,
                288,
                2744,
                3166,
                4591,
                1650,
                56,
                3015,
                1880,
                36,
                4888,
                92,
                6307,
                4160,
                475,
                4045,
                639,
                3182,
                7299,
                5402,
                5473,
                7144,
                4121,
                1592,
                4817,
                2745,
                2681,
                7254,
                7290,
                7349,
                7797,
                3934,
                451,
                4210,
                3743,
                119,
                1600,
                235,
                3873,
                5386,
                6859,
                2907,
                4109,
                4332,
                810,
                592,
                792,
                5503,
                4995,
                5800,
                6316,
                3823,
                4801,
                4531,
                6714,
                538,
                4835,
                247,
                3770,
                5655,
                4107,
                1484,
                3200,
                4123,
                7184,
                4066,
                4099,
                6834,
                4915,
                716,
                5210,
                4036,
                4652,
                5556,
                4515,
                7065,
                4271,
                3165,
                3233,
                5457,
                4290,
                7372,
                1217,
                4879,
                3602,
                3162,
                3365,
                5732,
                4951,
                5969,
                4513,
                4808,
                7331,
                1915,
                462,
                2443,
                2222,
                1003,
                1099,
                3466,
                3386,
                3131,
                730,
                6552,
                4519,
                6795,
                5718,
                3217,
                2909,
                1269,
                6381,
                2826,
                3476,
                5339,
                5695,
                4203,
                3860,
                4820,
                6108,
                5226,
                3445,
                6196,
                2955,
                5564,
                2390,
                3429,
                588,
                4020,
                5724,
                3130,
                3788,
                7204,
                2919,
                3965,
                4338,
                3684,
                6731,
                684,
                1095,
                4651,
                2444,
                894,
                7281,
                19,
                434,
                5686,
                5883,
                1433,
                7796,
                7651,
                5938,
                1156,
                933,
                2086,
                6825,
                7063,
                6341,
                1748,
                329,
                386,
                3924,
                1581,
                7147,
                573,
                3453,
                2365,
                985,
                2598,
                4853,
                347,
                5956,
                4380,
                664,
                1643,
                51,
                2286,
                6461,
                912,
                6528,
                4,
                184,
                5241,
                3975,
                4924,
                6747,
                54,
                5073,
                428,
                2837,
                1749,
                4543,
                2320,
                5509,
                3768,
                2226,
                4111,
                2004,
                2130,
                4966,
                7072,
                2157,
                5816,
                2850,
                2662,
                190,
                2993,
                5173,
                6023,
                2195,
                6771,
                1435,
                5521,
                6254,
                2200,
                4329,
                4796,
                2181,
                4939,
                2953,
                5066,
                7594,
                75,
                4466,
                5141,
                2020,
                5974,
                1838,
                5182,
                4278,
                2294,
                1199,
                4587,
                740,
                7519,
                4162,
                5118,
                234,
                5855,
                5970,
                1638,
                2743,
                688,
                5185,
                7473,
                5193,
                6083,
                5834,
                4724,
                6066,
                7568,
                6633,
                4443,
                139,
                2173,
                2803,
                7174,
                5973,
                6700,
                6302,
                2041,
                5684,
                4343,
                986,
                4643,
                6736,
                3507,
                3185,
                5139,
                555,
                2540,
                5207,
                4114,
                6226,
                1609,
                7093,
                3282,
                5400,
                6793,
                7253,
                1428,
                1987,
                3286,
                2432,
                7051,
                3837,
                4648,
                298,
                1474,
                2347,
                5476,
                1823,
                682,
                1177,
                954,
                6607,
                3239,
                284,
                6413,
                3949,
                1063,
                5854,
                3555,
                4559,
                6351,
                7109,
                6536,
                3426,
                6040,
                4190,
                7323,
                4885,
                4064,
                4546,
                2091,
                5036,
                5585,
                1593,
                1180,
                2205,
                4182,
                6363,
                4112,
                2168,
                546,
                891,
                6186,
                1973,
                2733,
                3045,
                6707,
                6554,
                6506,
                1457,
                5807,
                806,
                4813,
                7370,
                4341,
                3815,
                4416,
                4132,
                421,
                6415,
                6375,
                5379,
                4293,
                7168,
                800,
                4861,
                6279,
                701,
                968,
                4956,
                2426,
                2056,
                3736,
                6189,
                7146,
                2146,
                1327,
                4942,
                620,
                3581,
                3575,
                6914,
                5799,
                560,
                2069,
                4684,
                6901,
                1928,
                5189,
                5536,
                5959,
                7092,
                502,
                4929,
                2372,
                1436,
                2965,
                2626,
                4126,
                1858,
                878,
                183,
                3497,
                5746,
                4327,
                726,
                6349,
                5716,
                4671,
                4541,
                6247,
                2796,
                5968,
                5813,
                634,
                5267,
                6180,
                2828,
                6328,
                4209,
                4672,
                6194,
                381,
                3570,
                1323,
                1680,
                4708,
                5342,
                3696,
                3485,
                3460,
                5294,
                4983,
                3227,
                7312,
                4056,
                6593,
                4247,
                5689,
                1392,
                6876,
                5921,
                2734,
                3760,
                7399,
                5537,
                776,
                3368,
                5887,
                3208,
                4021,
                4425,
                6898,
                3073,
                3318,
                6995,
                3017,
                6664,
                882,
                4558,
                3982,
                4051,
                4491,
                4017,
                490,
                3192,
                3071,
                67,
                3803,
                3834,
                6350,
                1553,
                5787,
                3014,
                6246,
                5250,
                7268,
                1566,
                2724,
                2874,
                2344,
                6991,
                6197,
                5540,
                4781,
                7228,
                1290,
                4918,
                2386,
                4303,
                3955,
                960,
                1744,
                2943,
                6239,
                5827,
                532,
                3890,
                5578,
                406,
                2068,
                2139,
                6688,
                820,
                1141,
                1544,
                4410,
                2349,
                3859,
                6860,
                1554,
                6846,
                330,
                6392,
                5614,
                7633,
                1972,
                2877,
                3043,
                2465,
                6287,
                5776,
                2414,
                3504,
                851,
                353,
                869,
                535,
                1208,
                5026,
                4359,
                3436,
                1135,
                6092,
                2403,
                5914,
                666,
                6589,
                5870,
                778,
                1300,
                513,
                1654,
                5768,
                5765,
                256,
                2315,
                1219,
                1186,
                4068,
                6814,
                530,
                3350,
                3261,
                617,
                1537,
                336,
                667,
                2080,
                280,
                7608,
                5700,
                1194,
                1669,
                4712,
                6968,
                914,
                3451,
                3515,
                3660,
                6828,
                2224,
                6430,
                1725,
                2765,
                6856,
                3820,
                5615,
                964,
                979,
                6724,
                5849,
                4407,
                4831,
                512,
                3543,
                6823,
                2917,
                6433,
                3618,
                3397,
                3399,
                3427,
                3754,
                2242,
                1038,
                6314,
                6679,
                996,
                205,
                2682,
                3308,
                3546,
                4371,
                7261,
                4269,
                4880,
                334,
                7277,
                2473,
                219,
                3225,
                355,
                3251,
                7250,
                4522,
                4197,
                6984,
                731,
                4673,
                7137,
                5471,
                3094,
                4322,
                5901,
                3939,
                1899,
                511,
                536,
                5758,
                6032,
                2552,
                1466,
                647,
                4807,
                3102,
                6208,
                424,
                539,
                6629,
                3032,
                1666,
                5377,
                1173,
                3040,
                3561,
                5110,
                4785,
                3158,
                3061,
                5662,
                3734,
                4758,
                3903,
                6319,
                3222,
                4240,
                5805,
                1562,
                6977,
                1127,
                176,
                2482,
                6477,
                5760,
                6980,
                3628,
                583,
                6585,
                1168,
                4365,
                6025,
                7543,
                2023,
                6046,
                1740,
                687,
                1616,
                1699,
                3525,
                2575,
                382,
                4122,
                6486,
                3925,
                6737,
                389,
                3354,
                2546,
                1404,
                7154,
                5802,
                4719,
                266,
                1264,
                6050,
                4357,
                1857,
                5146,
                2198,
                3295,
                6873,
                3106,
                3994,
                1980,
                1998,
                168,
                5560,
                756,
                2852,
                3585,
                3004,
                4194,
                3415,
                4402,
                1591,
                4086,
                6698,
                2824,
                5441,
                1409,
                2017,
                3517,
                4147,
                2113,
                897,
                1497,
                728,
                2544,
                6529,
                4538,
                258,
                4257,
                1185,
                577,
                5803,
                1444,
                6597,
                6493,
                5369,
                5143,
                4489,
                68,
                3997,
                7325,
                5930,
                6671,
                1224,
                109,
                1966,
                1762,
                7723,
                4295,
                4308,
                3367,
                6535,
                5848,
                6110,
                2637,
                4970,
                6271,
                5761,
                6587,
                3181,
                4911,
                832,
                2511,
                1780,
                2695,
                2957,
                1429,
                7500,
                158,
                7805,
                2458,
                4806,
                3532,
                4237,
                6439,
                1236,
                2634,
                2062,
                755,
                5236,
                3967,
                672,
                6121,
                515,
                6011,
                1529,
                2618,
                4355,
                1031,
                2460,
                3795,
                1209,
                5358,
                2706,
                6041,
                1522,
                3805,
                2789,
                6632,
                2371,
                1687,
                595,
                390,
                3214,
                238,
                5597,
                746,
                879,
                5407,
                1757,
                3080,
                745,
                2759,
                332,
                1276,
                7545,
                1760,
                3616,
                518,
                939,
                4836,
                4264,
                2311,
                4127,
                1679,
                6565,
                5087,
                6182,
                769,
                5734,
                663,
                1367,
                5360,
                2408,
                6192,
                7727,
                2764,
                630,
                233,
                7569,
                308,
                3542,
                2019,
                2138,
                1855,
                2389,
                2638,
                1693,
                6410,
                6726,
                6365,
                4292,
                7404,
                4409,
                6672,
                279,
                90,
                4511,
                86,
                1450,
                1226,
                412,
                2517,
                5890,
                2749,
                4307,
                2869,
                6436,
                7,
                1278,
                5755,
                7028,
                1155,
                2721,
                7226,
                3750,
                1321,
                1388,
                1765,
                6280,
                6567,
                4487,
                6132,
                4460,
                5029,
                5927,
                5480,
                4659,
                2942,
                1046,
                7402,
                3645,
                7152,
                2388,
                1508,
                1345,
                5127,
                4593,
                1731,
                6172,
                6001,
                5088,
                4577,
                591,
                5999,
                2413,
                917,
                5287,
                3409,
                4877,
                221,
                6248,
                7522,
                6868,
                485,
                4750,
                3608,
                5047,
                2354,
                3931,
                5504,
                5106,
                6911,
                7451,
                4330,
                3058,
                3733,
                1941,
                6356,
                2060,
                6606,
                4060,
                789,
                2234,
                186,
                5579,
                6016,
                6513,
                4430,
                4555,
                3463,
                2057,
                3970,
                1120,
                5228,
                6146,
                6942,
                680,
                3311,
                1953,
                7321,
                1493,
                5563,
                473,
                6900,
                6713,
                938,
                7600,
                5375,
                5056,
                6065,
                3531,
                309,
                1878,
                1660,
                2987,
                4461,
                1360,
                2319,
                1503,
                261,
                2514,
                7007,
                6670,
                3201,
                732,
                500,
                5164,
                6923,
                1958,
                3874,
                6676,
                4765,
                4680,
                3530,
                2232,
                2166,
                5665,
                2114,
                5981,
                7197,
                64,
                2521,
                2808,
                2337,
                1458,
                4096,
                3056,
                6130,
                6964,
                4249,
                710,
                3990,
                2210,
                4524,
                358,
                3592,
                3712,
                1991,
                928,
                2783,
                4038,
                4754,
                2072,
                5212,
                1111,
                847,
                7076,
                5983,
                314,
                1340,
                4534,
                1788,
                1218,
                3954,
                5598,
                4780,
                3787,
                3563,
                4609,
                6635,
                6498,
                2671,
                5923,
                5374,
                5569,
                1258,
                1782,
                1307,
                4640,
                6653,
                213,
                5147,
                7629,
                5266,
                4655,
                7345,
                6462,
                527,
                4248,
                4540,
                6908,
                1723,
                5192,
                1394,
                2507,
                345,
                3587,
                5282,
                2207,
                6705,
                5944,
                7172,
                3270,
                155,
                4904,
                4586,
                5286,
                6387,
                6175,
                4991,
                2475,
                708,
                283,
                1251,
                3474,
                4367,
                3402,
                1903,
                6701,
                5011,
                3789,
                6291,
                7012,
                3422,
                5703,
                6599,
                217,
                1882,
                1525,
                2129,
                4300,
                4822,
                5804,
                2412,
                2563,
                5582,
                2282,
                3624,
                802,
                1555,
                6548,
                5188,
                2522,
                1839,
                1721,
                5515,
                2868,
                1123,
                7496,
                4108,
                815,
                3974,
                5573,
                4029,
                1938,
                3910,
                2602,
                991,
                2449,
                3667,
                5177,
                3722,
                1908,
                5380,
                5533,
                2359,
                3951,
                1527,
                1910,
                3705,
                39,
                3915,
                2273,
                3408,
                2299,
                3539,
                1349,
                4569,
                893,
                887,
                6514,
                53,
                43,
                4156,
                6167,
                416,
                2888,
                6617,
                5100,
                4632,
                5673,
                5535,
                1847,
                4503,
                3218,
                1615,
                4053,
                4961,
                2600,
                2720,
                4185,
                6899,
                5218,
                3883,
                4692,
                4166,
                4570,
                147,
                2904,
                528,
                3689,
                4235,
                2493,
                7064,
                3882,
                510,
                3346,
                1801,
                5290,
                3632,
                3639,
                764,
                5530,
                3862,
                4207,
                3886,
                3895,
                3471,
                772,
                6570,
                6725,
                1783,
                501,
                3163,
                7085,
                7332,
                4916,
                6338,
                1767,
                4912,
                6414,
                4311,
                5568,
                5552,
                902,
                130,
                773,
                7119,
                3343,
                5651,
                1861,
                1866,
                6598,
                2176,
                5884,
                5697,
                4957,
                6610,
                7135,
                4777,
                6910,
                5419,
                7251,
                3030,
                6561,
                6310,
                50,
                2677,
                3907,
                3330,
                6223,
                1963,
                1986,
                506,
                1711,
                2218,
                5874,
                5487,
                6628,
                6183,
                3651,
                6755,
                2366,
                5576,
                721,
                4226,
                931,
                824,
                3622,
                1183,
                5251,
                5003,
                7656,
                2486,
                2801,
                6048,
                5052,
                2882,
                4697,
                2814,
                4138,
                2119,
                5759,
                6308,
                7631,
                1373,
                2931,
                5519,
                405,
                2611,
                7729,
                6748,
                1943,
                4284,
                4747,
                294,
                7573,
                1536,
                2885,
                380,
                5465,
                1637,
                6594,
                6492,
                4824,
                4406,
                1073,
                4736,
                5714,
                1825,
                1309,
                5398,
                3153,
                1175,
                3369,
                2453,
                4575,
                6496,
                1677,
                6960,
                3713,
                5688,
                679,
                6924,
                4969,
                2009,
                476,
                2607,
                5806,
                1010,
                1886,
                2737,
                5797,
                1540,
                5015,
                2915,
                6880,
                1298,
                140,
                2289,
                7136,
                274,
                597,
                5934,
                885,
                5116,
                1256,
                926,
                1382,
                1459,
                6485,
                3210,
                6636,
                1374,
                6243,
                3991,
                3908,
                1213,
                5595,
                6839,
                840,
                7346,
                95,
                1578,
                6794,
                2819,
                6558,
                5099,
                2105,
                3113,
                4169,
                5154,
                3688,
                32,
                6330,
                2348,
                4572,
                5666,
                2462,
                5284,
                1418,
                6237,
                4878,
                4775,
                1100,
                326,
                6947,
                1359,
                4876,
                1197,
                3933,
                1228,
                6564,
                998,
                1420,
                6994,
                3362,
                3848,
                3995,
                3635,
                4174,
                34,
                5619,
                5845,
                6801,
                678,
                293,
                3992,
                4033,
                152,
                1350,
                734,
                6039,
                6986,
                1934,
                2735,
                3054,
                4452,
                625,
                6472,
                2435,
                899,
                5635,
                3096,
                4870,
                5347,
                875,
                1845,
                2675,
                4434,
                7248,
                5327,
                4644,
                2932,
                4254,
                3806,
                6933,
                6489,
                1696,
                2726,
                5712,
                1078,
                1939,
                997,
                7474,
                2075,
                5368,
                4059,
                2792,
                151,
                6799,
                4141,
                4725,
                2688,
                3756,
                4635,
                7369,
                3245,
                2624,
                6905,
                3376,
                5979,
                4599,
                4896,
                7053,
                1658,
                2276,
                7183,
                3609,
                5275,
                2854,
                6882,
                3987,
                1515,
                492,
                3193,
                2281,
                2422,
                5895,
                454,
                7342,
                1646,
                7112,
                2703,
                7089,
                4133,
                2470,
                4614,
                445,
                5248,
                7014,
                7291,
                3382,
                714,
                6509,
                6926,
                1024,
                841,
                969,
                1205,
                4946,
                3867,
                4962,
                5736,
                3617,
                5271,
                7544,
                2478,
                5132,
                2525,
                5893,
                4700,
                5219,
                2807,
                377,
                5867,
                5244,
                5580,
                7049,
                7547,
                3802,
                7139,
                3358,
                7178,
                813,
                3621,
                2896,
                5145,
                7061,
                4701,
                5324,
                4241,
                4206,
                4761,
                5864,
                873,
                1143,
                6171,
                6116,
                4563,
                4282,
                7207,
                3625,
                3423,
                3885,
                199,
                1667,
                496,
                3536,
                2431,
                2145,
                924,
                5199,
                5149,
                2121,
                2368,
                2326,
                3727,
                3405,
                3822,
                4234,
                2170,
                698,
                5604,
                6206,
                1995,
                6139,
                2061,
                829,
                6655,
                2865,
                2787,
                861,
                3278,
                104,
                5865,
                5762,
                1614,
                4887,
                1041,
                3547,
                6210,
                1634,
                1102,
                4215,
                791,
                633,
                2236,
                448,
                1411,
                4960,
                2209,
                4628,
                4666,
                5514,
                425,
                2564,
                2208,
                3794,
                1769,
                4368,
                1461,
                5751,
                2912,
                4104,
                2110,
                5824,
                6320,
                5238,
                2312,
                2360,
                2988,
                3556,
                1313,
                3956,
                2214,
                2936,
                3902,
                4936,
                4535,
                2769,
                909,
                4695,
                1756,
                7071,
                6372,
                5405,
                1443,
                3221,
                464,
                6055,
                1347,
                4037,
                3672,
                1911,
                6104,
                6618,
                2285,
                6408,
                1968,
                4227,
                5892,
                5551,
                4495,
                4442,
                1195,
                6733,
                1912,
                2960,
                1011,
                4336,
                1184,
                4035,
                3107,
                2770,
                978,
                1894,
                6784,
                1385,
                7278,
                6956,
                5977,
                379,
                3764,
                3706,
                3596,
                5455,
                1531,
                5422,
                6080,
                7043,
                5739,
                7329,
                7187,
                3122,
                7108,
                2150,
                2648,
                1528,
                5862,
                3301,
                3039,
                472,
                693,
                5350,
                49,
                3984,
                2548,
                242,
                5117,
                4421,
                126,
                5084,
                2231,
                3262,
                6358,
                598,
                3569,
                4018,
                5625,
                3119,
                551,
                4118,
                5738,
                5566,
                4595,
                6881,
                6465,
                4431,
                2719,
                1571,
                1248,
                6894,
                313,
                5525,
                3111,
                5051,
                4809,
                5905,
                5753,
                1709,
                4172,
                497,
                3089,
                1244,
                2346,
                1918,
                1811,
                4658,
                6504,
                5961,
                4488,
                6872,
                523,
                2279,
                1718,
                2941,
                2805,
                6411,
                3387,
                941,
                1504,
                5428,
                3552,
                5305,
                2603,
                3544,
                6449,
                1390,
                974,
                2804,
                5445,
                4913,
                6241,
                2582,
                1291,
                2065,
                6650,
                6852,
                6088,
                5678,
                6499,
                904,
                7330,
                5745,
                215,
                2524,
                7748,
                2601,
                5055,
                2361,
                5256,
                843,
                333,
                7298,
                2616,
                7471,
                2951,
                383,
                365,
                6533,
                579,
                3613,
                4571,
                6663,
                6928,
                5065,
                6079,
                1115,
                2039,
                5263,
                6694,
                4346,
                4213,
                1365,
                189,
                1960,
                4974,
                5885,
                7070,
                5935,
                6918,
                1959,
                2193,
                3452,
                7166,
                5024,
                1826,
                2439,
                5340,
                2996,
                44,
                2998,
                3438,
                5511,
                7777,
                103,
                4664,
                856,
                2433,
                6853,
                5989,
                5608,
                3957,
                2197,
                2536,
                4310,
                1689,
                1568,
                1361,
                3242,
                2358,
                1817,
                2707,
                6029,
                6944,
                25,
                4483,
                1971,
                4097,
                2762,
                3112,
                3993,
                2000,
                3005,
                1975,
                6222,
                5443,
                2994,
                3662,
                6471,
                3469,
                4689,
                822,
                4157,
                7263,
                6003,
                2215,
                6281,
                5676,
                2966,
                862,
                3175,
                1318,
                491,
                1405,
                1431,
                1810,
                5965,
                2050,
                2477,
                6371,
                4561,
                2557,
                3412,
                12,
                2513,
                1551,
                4139,
                880,
                4309,
                4383,
                5423,
                5507,
                6081,
                6948,
                1547,
                4827,
                2180,
                2096,
                366,
                2555,
                7264,
                4486,
                3941,
                5418,
                6590,
                7206,
                4518,
                325,
                1001,
                5296,
                6787,
                6357,
                437,
                1988,
                2590,
                5257,
                5829,
                4220,
                6840,
                3197,
                4931,
                4661,
                2002,
                417,
                949,
                1442,
                6229,
                2124,
                2961,
                4953,
                2450,
                3052,
                558,
                1552,
                6870,
                3607,
                5074,
                5176,
                6424,
                1470,
                2731,
                1480,
                6989,
                4296,
                2916,
                1148,
                4612,
                1819,
                2887,
                1613,
                1985,
                5206,
                4823,
                1549,
                5605,
                559,
                4597,
                5197,
                1371,
                4262,
                5952,
                6255,
                4480,
                644,
                3000,
                3832,
                4098,
                3514,
                2307,
                407,
                3389,
                2001,
                6300,
                3459,
                5541,
                1468,
                7654,
                606,
                5269,
                5991,
                768,
                3711,
                623,
                3704,
                6958,
                604,
                2353,
                2151,
                2160,
                31,
                5394,
                900,
                2088,
                1210,
                1956,
                6147,
                7003,
                2162,
                670,
                4753,
                5297,
                4897,
                3044,
                2292,
                2815,
                5425,
                6527,
                576,
                2188,
                7021,
                2092,
                6460,
                957,
                2328,
                2033,
                5720,
                5016,
                4464,
                2529,
                759,
                467,
                2984,
                1325,
                4755,
                7653,
                1286,
                3070,
                2003,
                1630,
                706,
                1564,
                5245,
                5387,
                2456,
                206,
                3500,
                1534,
                6621,
                52,
                7475,
                7157,
                4645,
                6883,
                5180,
                888,
                116,
                1106,
                5778,
                6537,
                3404,
                1582,
                3595,
                2833,
                5451,
                6188,
                6332,
                2040,
                4259,
                4850,
                2549,
                6609,
                6402,
                203,
                3062,
                5161,
                611,
                6581,
                3434,
                5153,
                609,
                5449,
                2423,
                6283,
                7319,
                3088,
                2223,
                4742,
                3868,
                241,
                2700,
                1113,
                4228,
                1999,
                4424,
                1596,
                5681,
                4031,
                6199,
                5611,
                6692,
                7036,
                2107,
                1611,
                1308,
                5268,
                1145,
                3567,
                5922,
                6930,
                1864,
                6443,
                3857,
                948,
                7124,
                4893,
                5627,
                3835,
                616,
                6,
                5119,
                3057,
                3914,
                2296,
                6335,
                6448,
                1013,
                4646,
                4446,
                2082,
                3553,
                3854,
                2244,
                4699,
                7296,
                269,
                3952,
                7198,
                7423,
                1451,
                5126,
                5308,
                1058,
                1869,
                6850,
                1734,
                6601,
                1852,
                1089,
                6584,
                7297,
                3028,
                1434,
                3498,
                3324,
                5220,
                3098,
                1570,
                6131,
                2519,
                6244,
                3772,
                807,
                281,
                7286,
                5801,
                5040,
                3930,
                6154,
                6811,
                7215,
                6845,
                7257,
                3634,
                6861,
                4873,
                5947,
                315,
                5417,
                7287,
                6138,
                1629,
                690,
                619,
                5589,
                45,
                5408,
                6331,
                3240,
                198,
                3319,
                3845,
                6782,
                7800,
                3207,
                1652,
                3105,
                1675,
                5653,
                7165,
                6950,
                3019,
                6235,
                2576,
                4007,
                1836,
                2303,
                2322,
                649,
                6454,
                3801,
                7190,
                3983,
                6937,
                1898,
                409,
                7196,
                5231,
                4731,
                7262,
                1250,
                7210,
                6293,
                5007,
                4819,
                1786,
                4403,
                6027,
                2338,
                7208,
                18,
                7080,
                5211,
                821,
                5748,
                4647,
                7245,
                505,
                1187,
                1778,
                6997,
                4715,
                2083,
                6602,
                1692,
                4859,
                6797,
                7265,
                2510,
                4795,
                1932,
                4639,
                3971,
                5522,
                370,
                6142,
                6921,
                7289,
                3082,
                3333,
                3337,
                178,
                3437,
                952,
                2468,
                4791,
                6634,
                6177,
                5137,
                6473,
                1245,
                6622,
                2306,
                593,
                3296,
                4305,
                1020,
                4198,
                1751,
                1561,
                3958,
                3001,
                6474,
                763,
                7591,
                3893,
                4000,
                5607,
                4150,
                4253,
                6441,
                5005,
                1027,
                125,
                4499,
                4977,
                3413,
                2374,
                2527,
                6268,
                7103,
                1804,
                1942,
                3396,
                6135,
                3384,
                4028,
                6909,
                2560,
                5037,
                1701,
                6739,
                2472,
                3888,
                1476,
                2014,
                6059,
                4145,
                738,
                160,
                6249,
                7217,
                2702,
                6446,
                2255,
                5049,
                2786,
                5502,
                3259,
                2489,
                4592,
                285,
                1598,
                7042,
                354,
                2496,
                5691,
                3534,
                4016,
                5911,
                348,
                4840,
                4078,
                2013,
                1358,
                7704,
                7162,
                5190,
                7313,
                7127,
                351,
                4050,
                2131,
                4231,
                7219,
                7628,
                4103,
                2881,
                4512,
                3081,
                2031,
                4331,
                2396,
                268,
                387,
                6018,
                3359,
                7060,
                5777,
                5235,
                6920,
                4622,
                373,
                6673,
                402,
                4580,
                7381,
                6800,
                2505,
                3006,
                481,
                750,
                5876,
                1992,
                2851,
                4074,
                5215,
                1094,
                2657,
                6678,
                60,
                3069,
                4510,
                1599,
                1366,
                582,
                3199,
                1071,
                1867,
                6579,
                4578,
                3275,
                4153,
                6640,
                1597,
                4583,
                48,
                4245,
                4385,
                2923,
                669,
                6360,
                1873,
                328,
                1103,
                831,
                6236,
                7155,
                6037,
                2780,
                4926,
                5054,
                6044,
                4475,
                3441,
                6094,
                4675,
                5440,
                1408,
                5920,
                2272,
                2694,
                6941,
                4081,
                248,
                4688,
                2629,
                5906,
                5730,
                7143,
                3388,
                1758,
                774,
                1227,
                4553,
                5017,
                322,
                5389,
                1485,
                4244,
                7126,
                7308,
                1235,
                6754,
                4318,
                2051,
                3022,
                6769,
                3790,
                4046,
                3254,
                6893,
                3718,
                2964,
                6651,
                79,
                114,
                1247,
                3640,
                2038,
                5136,
                7128,
                5222,
                7802,
                4317,
                3728,
                420,
                631,
                2794,
                646,
                3611,
                3549,
                1589,
                1448,
                1093,
                7523,
                5446,
                7224,
                4449,
                3176,
                121,
                5070,
                5336,
                6764,
                4786,
                4899,
                2605,
                4277,
                4030,
                1070,
                1627,
                1140,
                6204,
                3840,
                1705,
                3598,
                5240,
                1237,
                6061,
                2144,
                6344,
                2752,
                1974,
                6325,
                4616,
                1797,
                4602,
                148,
                2266,
                1376,
                5819,
                1618,
                1863,
                6500,
                945,
                6173,
                5027,
                3361,
                1574,
                5784,
                7272,
                6517,
                483,
                6576,
                3110,
                4871,
                7151,
                2900,
                2583,
                166,
                91,
                2316,
                5699,
                3626,
                3614,
                1550,
                4869,
                5572,
                1875,
                3108,
                2585,
                6093,
                6064,
                6442,
                458,
                11,
                3940,
                6615,
                5061,
                6455,
                2827,
                2411,
                989,
                3926,
                433,
                3481,
                966,
                7609,
                2509,
                7069,
                1214,
                5794,
                7233,
                6045,
                7495,
                1049,
                2795,
                3966,
                110,
                4549,
                2911,
                794,
                4650,
                1079,
                2680,
                4884,
                5863,
                1328,
                4910,
                3591,
                7701,
                628,
                6054,
                1602,
                6641,
                650,
                1663,
                6611,
                3117,
                1315,
                987,
                6588,
                2093,
                3344,
                5663,
                6288,
                2381,
                2873,
                7242,
                2427,
                6778,
                5737,
                5701,
                3723,
                7078,
                1542,
                1416,
                4794,
                2516,
                2767,
                7123,
                723,
                6086,
                614,
                3053,
                5080,
                6051,
                7047,
                5310,
                1926,
                5886,
                210,
                6927,
                6940,
                270,
                5134,
                2323,
                6467,
                6572,
                6750,
                6386,
                1545,
                3891,
                7102,
                1996,
                4301,
                100,
                6781,
                3678,
                6857,
                6006,
                4863,
                5510,
                6721,
                3659,
                461,
                6985,
                2287,
                5353,
                2974,
                4342,
                6278,
                3065,
                6596,
                5283,
                96,
                781,
                5096,
                3503,
                946,
                5645,
                2136,
                3100,
                1035,
                7448,
                1119,
                6252,
                801,
                6710,
                5243,
                1257,
                4800,
                2503,
                5694,
                994,
                2379,
                3623,
                804,
                2274,
                3493,
                5259,
                1640,
                6919,
                4067,
                2732,
                2133,
                4372,
                7121,
                1639,
                1302,
                7039,
                3276,
                2813,
                2254,
                3247,
                1277,
                1087,
                4455,
                6768,
                2939,
                55,
                3619,
                4769,
                4506,
                6476,
                571,
                2995,
                4057,
                507,
                1755,
                4251,
                2599,
                1644,
                2978,
                1462,
                4481,
                3755,
                5499,
                5866,
                4497,
                3588,
                4297,
                1167,
                5262,
                6102,
                1204,
                1670,
                737,
                243,
                2476,
                1297,
                6260,
                3167,
                1032,
                6225,
                4685,
                6070,
                1754,
                6469,
                6181,
                6084,
                548,
                4094,
                6957,
                249,
                5102,
                6470,
                6783,
                42,
                2797,
                7632,
                3424,
                855,
                3620,
                1628,
                921,
                1118,
                563,
                585,
                1029,
                3154,
                7320,
                6009,
                5023,
                3920,
                1856,
                3372,
                1962,
                6285,
                316,
                1246,
                7195,
                3508,
                6669,
                6519,
                3442,
                138,
                6507,
                2268,
                7116,
                6242,
                2777,
                2938,
                4560,
                7322,
                3141,
                5478,
                561,
                6195,
                4805,
                4283,
                2613,
                6368,
                3665,
                4130,
                7118,
                6178,
                2156,
                1981,
                3394,
                4065,
                520,
                6049,
                4720,
                6403,
                516,
                27,
                2633,
                1952,
                3765,
                3953,
                6056,
                5735,
                5496,
                3685,
                202,
                2897,
                3496,
                5839,
                5356,
                5082,
                5725,
                5482,
                3033,
                1363,
                6946,
                2863,
                6903,
                1004,
                5793,
                5022,
                4564,
                1659,
                6809,
                6549,
                6547,
                7340,
                5485,
                2103,
                6637,
                564,
                1018,
                255,
                5875,
                5792,
                2109,
                4239,
                5945,
                915,
                4246,
                5721,
                4621,
                835,
                6150,
                3574,
                1739,
                3545,
                312,
                4740,
                6297,
                3769,
                7302,
                4678,
                7452,
                6321,
                3664,
                460,
                3916,
                4316,
                3571,
                7592,
                156,
                569,
                7094,
                1685,
                6057,
                4619,
                7149,
                6488,
                4379,
                2992,
                6546,
                2817,
                4683,
                1704,
                5028,
                4630,
                3735,
                4847,
                6822,
                5747,
                696,
                7006,
                5442,
                2377,
                4498,
                2523,
                3090,
                2550,
                3124,
                5351,
                1676,
                2864,
                6184,
                225,
                6089,
                5546,
                1142,
                6965,
                6530,
                5372,
                2678,
                2125,
                6115,
                7211,
                1062,
                6935,
                4093,
                1348,
                7111,
                3906,
                7548,
                2667,
                3074,
                1271,
                3695,
                2497,
                2032,
                6258,
                2840,
                6047,
                5766,
                6699,
                5501,
                2518,
                4143,
                6437,
                375,
                2639,
                6722,
                1069,
                6238,
                5516,
                2010,
                7018,
                7079,
                4940,
                1583,
                1877,
                638,
                5131,
                2959,
                5261,
                3447,
                7223,
                5555,
                3615,
                4728,
                1929,
                5142,
                3446,
                626,
                3331,
                6143,
                1519,
                3521,
                6020,
                6419,
                6129,
                5060,
                5148,
                2227,
                1486,
                2990,
                4764,
                1844,
                6973,
                1368,
                4882,
                4660,
                4691,
                3,
                2480,
                3944,
                7110,
                2696,
                4709,
                1641,
                1422,
                3123,
                400,
                6245,
                1495,
                7160,
                955,
                6103,
                6808,
                5167,
                5789,
                618,
                3103,
                2971,
                6156,
                1107,
                1707,
                5224,
                3708,
                4101,
                5001,
                2402,
                5093,
                540,
                1427,
                5458,
                2539,
                5629,
                5841,
                439,
                2504,
                6604,
                5279,
                323,
                3976,
                3719,
                972,
                1335,
                352,
                2035,
                7199,
                1842,
                6362,
                3564,
                782,
                4548,
                6820,
                2751,
                5388,
                2022,
                3649,
                3506,
                5896,
                3327,
                2070,
                7117,
                2799,
                6481,
                300,
                3629,
                1518,
                3551,
                1492,
                6024,
                5415,
                2793,
                2983,
                3348,
                717,
                4718,
                982,
                4291,
                4438,
                6993,
                3095,
                2562,
                6645,
                4397,
                1481,
                440,
                4905,
                5078,
                3557,
                1964,
                360,
                2515,
                5687,
                6812,
                6702,
                3969,
                216,
                1331,
                232,
                6008,
                5076,
                4186,
                4670,
                5786,
                6270,
                5949,
                4508,
                1201,
                2387,
                3948,
                808,
                6416,
                6456,
                4778,
                237,
                5744,
                5646,
                2790,
                6566,
                4917,
                1239,
                6592,
                5395,
                1054,
                3732,
                5872,
                871,
                5685,
                1579,
                1270,
                2979,
                5459,
                6992,
                1149,
                1151,
                1221,
                754,
                4348,
                2284,
                1750,
                7068,
                5032,
                5843,
                5314,
                3250,
                898,
                3878,
                3898,
                343,
                2288,
                7133,
                2233,
                2021,
                5561,
                4113,
                2740,
                866,
                2305,
                1766,
                4839,
                4485,
                7244,
                5851,
                2202,
                850,
                770,
                295,
                6555,
                6339,
                1879,
                2727,
                6730,
                2673,
                452,
                2270,
                5157,
                3010,
                6151,
                5833,
                621,
                2622,
                7045,
                3152,
                6343,
                3425,
                429,
                2922,
                35,
                2263,
                1514,
                906,
                4320,
                459,
                5397,
                6329,
                3833,
                5477,
                2578,
                4465,
                6878,
                3691,
                557,
                552,
                3856,
                2543,
                2342,
                6157,
                4711,
                4608,
                1230,
                4525,
                1110,
                5039,
                6490,
                2531,
                4034,
                967,
                4216,
                23,
                2547,
                78,
                6379,
                2641,
                5898,
                5534,
                83,
                4042,
                65,
                2258,
                5058,
                5461,
                5448,
                6813,
                6434,
                4366,
                1131,
                6706,
                4012,
                1890,
                547,
                7801,
                4603,
                1303,
                1580,
                7243,
                1487,
                5488,
                2620,
                457,
                4582,
                40,
                2340,
                6848,
                4388,
                2331,
                5838,
                1603,
                2142,
                5661,
                4707,
                2595,
                6865,
                7546,
                302,
                7075,
                3483,
                3565,
                981,
                5648,
                2126,
                4049,
                6075,
                1352,
                6107,
                5168,
                1114,
                2991,
                2558,
                4862,
                6005,
                3470,
                4427,
                5936,
                208,
                6007,
                6501,
                3899,
                2537,
                1000,
                4260,
                6421,
                5367,
                4376,
                5990,
                7141,
                167,
                2893,
                5962,
                1401,
                5170,
                6966,
                1052,
                5069,
                6452,
                863,
                2165,
                4772,
                586,
                766,
                5276,
                1065,
                2135,
                2332,
                657,
                4268,
                1984,
                2239,
                6761,
                6959,
                2385,
                5452,
                6266,
                6996,
                240,
                2199,
                533,
                1822,
                771,
                5856,
                5413,
                3173,
                1138,
                1983,
                6256,
                3779,
                4298,
                2591,
                3140,
                1940,
                1317,
                356,
                2856,
                5710,
                6677,
                5795,
                357,
                5359,
                4261,
                5975,
                3793,
                3923,
                2454,
                3661,
                1530,
                1179,
                2556,
                4615,
                5163,
                3393,
                5754,
                5150,
                4849,
                3744,
                7472,
                4713,
                6952,
                1835,
                478,
                3143,
                2753,
                7426,
                5479,
                4047,
                5599,
                713,
                3093,
                524,
                671,
                3149,
                6892,
                4790,
                7307,
                4478,
                486,
                6212,
                1152,
                1827,
                4456,
                3371,
                1994,
                2066,
                7067,
                5183,
                925,
                7316,
                2845,
                5966,
                4393,
                4981,
                149,
                7230,
                13,
                3573,
                7216,
                6982,
                107,
                4270,
                4378,
                3938,
                7273,
                2280,
                3329,
                3653,
                1463,
                5976,
                1521,
                7087,
                4191,
                4011,
                465,
                5472,
                3501,
                1066,
                5636,
                3699,
                1467,
                1708,
                3646,
                1262,
                6746,
                5460,
                6662,
                3693,
                7106,
                2467,
                3456,
                1241,
                2843,
                4382,
                6480,
                4607,
                5230,
                7324,
                839,
                6165,
                918,
                5963,
                6417,
                5172,
                2293,
                3155,
                1690,
                73,
                4373,
                2593,
                5343,
                6273,
                376,
                930,
                1091,
                6967,
                6954,
                1914,
                1978,
                3643,
                2152,
                2398,
                3880,
                277,
                603,
                1601,
                6816,
                6516,
                290,
                2012,
                5274,
                7054,
                7164,
                2212,
                654,
                2766,
                570,
                84,
                1736,
                7114,
                1353,
                514,
                575,
                2538,
                2614,
                608,
                4080,
                6580,
                5675,
                3568,
                668,
                4196,
                6521,
                2153,
                4131,
                1305,
                5494,
                6697,
                5913,
                153,
                411,
                2471,
                1354,
                3698,
                859,
                1710,
                6627,
                4137,
                6871,
                3905,
                2621,
                3986,
                3377,
                191,
                5647,
                7097,
                5008,
                4999,
                1306,
                4200,
                655,
                1399,
                653,
                5320,
                7343,
                3129,
                3594,
                6426,
                2761,
                2918,
                7082,
                7379,
                2772,
                97,
                6117,
                2899,
                5208,
                3450,
                3889,
                2474,
                4265,
                1272,
                5373,
                1916,
                4930,
                7810,
                1316,
                2391,
                753,
                7344,
                1881,
                4928,
                2278,
                6395,
                4312,
                2975,
                7275,
                1923,
                1223,
                2429,
                5909,
                1556,
                3612,
                4288,
                4009,
                6709,
                3137,
                5321,
                4002,
                2229,
                446,
                5809,
                2461,
                6218,
                2718,
                6858,
                1421,
                2910,
                1850,
                3291,
                1793,
                6277,
                6374,
                3838,
                4386,
                6304,
                7367,
                777,
                4662,
                2097,
                2642,
                6438,
                7285,
                6111,
                4255,
                6053,
                3510,
                1798,
                5588,
                6827,
                2784,
                858,
                1025,
                3809,
                6030,
                6591,
                5333,
                2656,
                135,
                4405,
                6961,
                6169,
                4596,
                3036,
                6642,
                651,
                5749,
                7145,
                4812,
                3527,
                5639,
                2364,
                3516,
                7209,
                980,
                4482,
                1423,
                4516,
                6539,
                6638,
                6168,
                3842,
                748,
                470,
                6382,
                2464,
                3177,
                7125,
                3524,
                5626,
                927,
                2647,
                942,
                2238,
                3746,
                6929,
                3118,
                4183,
                3909,
                2500,
                3285,
                455,
                2750,
                4721,
                2499,
                7567,
                3784,
                422,
                3172,
                6595,
                7134,
                1532,
                3911,
                2581,
                7193,
                1092,
                201,
                803,
                2058,
                1162,
                2327,
                5406,
                1383,
                6309,
                2791,
                374,
                7191,
                4756,
                5315,
                4567,
                1166,
                2178,
                6282,
                6907,
                3430,
                758,
                5948,
                392,
                5868,
                2321,
                1164,
                3578,
                699,
                5998,
                5899,
                2174,
                5366,
                2074,
                4667,
                2100,
                2183,
                5621,
                3821,
                7022,
                3253,
                913,
                124,
                4933,
                5951,
                7240,
                5919,
                5581,
                1795,
                4280,
                4089,
                4106,
                4159,
                4392,
                4902,
                7073,
                1121,
                1489,
                4837,
                3686,
                2716,
                2654,
                1871,
                1203,
                3183,
                3226,
                5059,
                7000,
                6214,
                6298,
                4273,
                4598,
                6625,
                259,
                6269,
                6978,
                2120,
                562,
                2137,
                6717,
                1337,
                5434,
                2267,
                5104,
                1215,
                2485,
                4528,
                2187,
                7221,
                3980,
                4148,
                3433,
                2373,
                6538,
                1425,
                3737,
                5194,
                2407,
                837,
                4949,
                6666,
                163,
                4562,
                418,
                3638,
                3927,
                6353,
                798,
                6508,
                2446,
                6153,
                1125,
                5289,
                2216,
                7062,
                6354,
                1301,
                3455,
                4937,
                6216,
                2714,
                992,
                7171,
                2418,
                4803,
                5828,
                2079,
                4412,
                4770,
                3428,
                1048,
                1280,
                1397,
                3981,
                4389,
                1743,
                4347,
                3753,
                5764,
                6543,
                601,
                6847,
                4315,
                5213,
                3601,
                2976,
                6391,
                719,
                6854,
                5196,
                1664,
                2494,
                1473,
                2674,
                3206,
                1260,
                1377,
                4304,
                4752,
                3766,
                4789,
                3298,
                102,
                2148,
                6563,
                4165,
                4222,
                2008,
                4054,
                1261,
                4006,
                3777,
                5493,
                1268,
                4527,
                3292,
                4119,
                5470,
                164,
                1682,
                6388,
                6821,
                5722,
                5000,
                1805,
                6556,
                4865,
                1479,
                2184,
                4154,
                1697,
                6348,
                2029,
                6021,
                6766,
                5130,
                2534,
                6987,
                6232,
                1501,
                1384,
                388,
                1924,
                6826,
                4509,
                4825,
                7122,
                3011,
                2483,
                2357,
                391,
                6058,
                1083,
                613,
                1843,
                6925,
                3495,
                1505,
                1126,
                413,
                2628,
                2968,
                3702,
                7107,
                1686,
                5559,
                6999,
                4952,
                5337,
                1396,
                2245,
                7008,
                5640,
                1154,
                5214,
                6373,
                4212,
                3773,
                5912,
                3812,
                6681,
                2969,
                415,
                5726,
                4048,
                5941,
                3448,
                2520,
                5298,
                6740,
                4458,
                2046,
                6176,
                5249,
                5427,
                6824,
                6451,
                108,
                2594,
                2007,
                6447,
                2064,
                7205,
                6649,
                5785,
                5160,
                1496,
                5601,
                401,
                7231,
                7752,
                2742,
                5014,
                4069,
                765,
                581,
                5950,
                3097,
                849,
                934,
                194,
                6364,
                338,
                3351,
                6209,
                4972,
                4627,
                6975,
                327,
                4039,
                3763,
                7267,
                5549,
                3600,
                7293,
                3707,
                2190,
                4022,
                471,
                4135,
                6690,
                5404,
                6773,
                185,
                2660,
                1883,
                6326,
                3776,
                3816,
                4072,
                1338,
                6201,
                5254,
                4851,
                3973,
                2204,
                2067,
                5439,
                2825,
                6012,
                4136,
                1517,
                6466,
                5362,
                600,
                1090,
                3579,
                3548,
                3826,
                6491,
                4062,
                5391,
                1606,
                3814,
                3213,
                2492,
                7427,
                2240,
                3055,
                6400,
                6804,
                4361,
                1294,
                4128,
                3249,
                6644,
                6333,
                3224,
                7607,
                4230,
                3395,
                291,
                3703,
                767,
                5489,
                4077,
                3739,
                4674,
                7167,
                1153,
                4398,
                1198,
                4436,
                1042,
                3972,
                5933,
                6384,
                7747,
                5095,
                4741,
                246,
                1784,
                911,
                665,
                181,
                2692,
                1414,
                1763,
                643,
                3761,
                2108,
                1222,
                5978,
                2219,
                645,
                929,
                1225,
                7083,
                2949,
                4492,
                251,
                4799,
                7015,
                3513,
                7771,
                214,
                4490,
                1334,
                6305,
                5584,
                1742,
                5312,
                1642,
                4771,
                4369,
                5205,
                6904,
                7726,
                7336,
                5335,
                3281,
                689,
                499,
                3196,
                3494,
                159,
                3511,
                1834,
                4176,
                3048,
                1576,
                5378,
                1182,
                4545,
                4149,
                4638,
                1395,
                4892,
                2440,
                1007,
                3912,
                6932,
                146,
                884,
                3077,
                3817,
                6767,
                702,
                5668,
                7132,
                1853,
                3159,
                477,
                4073,
                3302,
                1402,
                2309,
                3002,
                2672,
                5692,
                3340,
                6406,
                4079,
                9,
                4435,
                6227,
                1240,
                3844,
                2466,
                4396,
                5288,
                4746,
                1330,
                1785,
                2986,
                6720,
                4682,
                2758,
                662,
                5198,
                349,
                1189,
                3884,
                2230,
                3364,
                3603,
                2221,
                6916,
                4353,
                4507,
                3830,
                3932,
                2834,
                6369,
                7173,
                3134,
                4377,
                2363,
                6267,
                7038,
                1813,
                5554,
                5524,
                6866,
                6495,
                2330,
                2676,
                2329,
                1796,
                6939,
                484,
                320,
                4733,
                4730,
                5527,
                1506,
                112,
                1055,
                2778,
                1047,
                2298,
                3663,
                4415,
                3049,
                2771,
                3541,
                6290,
                5558,
                3597,
                3978,
                4842,
                2037,
                6833,
                811,
                795,
                1477,
                5233,
                1700,
                4418,
                5832,
                6422,
                5260,
                6022,
                6459,
                4299,
                7081,
                5265,
                5018,
                2554,
                2810,
                2901,
                5334,
                3605,
                4221,
                7220,
                1904,
                5810,
                2469,
                5365,
                5454,
                2950,
                1703,
                7113,
                3644,
                3087,
                4589,
                3235,
                1400,
                6851,
                273,
                1502,
                4886,
                5693,
                4351,
                4975,
                4907,
                443,
                5889,
                5954,
                4287,
                2275,
                2154,
                1036,
                1672,
                4668,
                6289,
                2551,
                2526,
                4364,
                6148,
                2171,
                3341,
                5490,
                5121,
                3289,
                5382,
                2343,
                1370,
                6613,
                4544,
                743,
                4232,
                6072,
                4935,
                2034,
                2972,
                7041,
                5025,
                6647,
                7348,
                4909,
                757,
                4950,
                1820,
                7750,
                7751,
                4087,
                2256,
                2690,
                3067,
                4690,
                5414,
                4187,
                3655,
                4325,
                2822,
                3894,
                5242,
                85,
                1483,
                1831,
                6759,
                5526,
                6573,
                1656,
                3537,
                3964,
                2906,
                846,
                222,
                480,
                7052,
                2488,
                3083,
                4116,
                1096,
                2141,
                172,
                5882,
                7153,
                3026,
                7655,
                3383,
                2708,
                2812,
                4653,
                1178,
                2043,
                4568,
                2875,
                384,
                5225,
                5184,
                5156,
                6200,
                4866,
                5255,
                2228,
                7034,
                2892,
                3781,
                6770,
                6569,
                1509,
                4533,
                6085,
                2710,
                3484,
                3819,
                3381,
                6776,
                6035,
                4428,
                3528,
                7702,
                4637,
                683,
                1104,
                3104,
                3687,
                3486,
                5996,
                5009,
                3144,
                5596,
                4768,
                883,
                7326,
                58,
                4432,
                874,
                4726,
                5361,
                41,
                7703,
                5847,
                599,
                5840,
                5323,
                4321,
                4982,
                5020,
                3675,
                7011,
                6294,
                751,
                3936,
                1969,
                5123,
                2933,
                5328,
                47,
                3877,
                7175,
                4774,
                410,
                6211,
                2632,
                1212,
                395,
                999,
                5723,
                3657,
                6370,
                5491,
                4400,
                4267,
                136,
                7292,
                6207,
                537,
                1378,
                6760,
                2588,
                5162,
                3774,
                1884,
                1584,
                3960,
                3512,
                5089,
                2573,
                4705,
                6361,
                1285,
                2249,
                7202,
                1651,
                5644,
                825,
                2970,
                962,
                4855,
                5234,
                1621,
                2535,
                4326,
                80,
                2247,
                134,
                2132,
                3778,
                5982,
                6261,
                5435,
                7229,
                1259,
                1288,
                3671,
                2106,
                1439,
                4993,
                6450,
                5178,
                3701,
                1569,
                5704,
                6560,
                2589,
                2182,
                5179,
                5124,
                1896,
                1588,
                6523,
                3046,
                7288,
                4714,
                4938,
                2627,
                594,
                1806,
                169,
                2185,
                4189,
                5120,
                6836,
                2569,
                5129,
                1741,
                2099,
                3487,
                3255,
                2161,
                1722,
                3419,
                2650,
                226,
                2127,
                4401,
                3420,
                5306,
                7772,
                324,
                787,
                3435,
                741,
                3759,
                5239,
                5437,
                5278,
                5246,
                4188,
                2271,
                6624,
                5548,
                1398,
                4055,
                6378,
                4229,
                6140,
                817,
                3161,
                4411,
                6757,
                6951,
                6101,
                6367,
                5409,
                2691,
                6432,
                1419,
                62,
                1284,
                4745,
                2395,
                7341,
                1691,
                271,
                3599,
                2684,
                1575,
                865,
                1158,
                4075,
                4605,
                4358,
                5456,
                267,
                6026,
                4681,
                828,
                705,
                892,
                3059,
                2619,
                2487,
                6091,
                4102,
                5299,
                4868,
                4581,
                1437,
                5371,
                1791,
                1526,
                2587,
                3461,
                3385,
                30,
                1681,
                6829,
                961,
                6890,
                2495,
                6284,
                2669,
                2445,
                4556,
                4657,
                4445,
                1631,
                6253,
                2653,
                6445,
                944,
                81,
                5719,
                1837,
                4826,
                1781,
                7016,
                1002,
                3872,
                4821,
                5447,
                6817,
                212,
                3959,
                2925,
                4184,
                5067,
                5775,
                1146,
                5796,
                4242,
                5033,
                3538,
                6087,
                2128,
                1792,
                648,
                7189,
                7593,
                2225,
                5041,
                4997,
                6723,
                1161,
                1379,
                2763,
                3114,
                5817,
                5574,
                2382,
                6464,
                1770,
                3458,
                5771,
                6340,
                1967,
                4606,
                936,
                4493,
                5071,
                6034,
                1351,
                1074,
                5293,
                2830,
                5433,
                7120,
                4433,
                2879,
                4604,
                4520,
                6342,
                1563,
                4420,
                605,
                4314,
                676,
                5062,
                783,
                2314,
                834,
                2958,
                5632,
                4019,
                364,
                4703,
                337,
                3008,
                1870,
                3700,
                7002,
                3863,
                674,
                4161,
                5869,
                6630,
                7375,
                1137,
                7163,
                1196,
                4501,
                3392,
                6128,
                1787,
                3091,
                4404,
                3198,
                2098,
                6193,
                6553,
                5740,
                1343,
                1608,
                1732,
                479,
                2006,
                2821,
                920,
                1982,
                7142,
                6482,
                7284,
                1329,
                3943,
                1851,
                6396,
                2345,
                4732,
                16,
                7090,
                1777,
                2687,
                692,
                2741,
                82,
                4925,
                317,
                438,
                1849,
                3188,
                5782,
                1688,
                3472,
                3963,
                1266,
                6220,
                5304,
                4921,
                3072,
                2335,
                6240,
                6389,
                4676,
                1454,
                4363,
                1889,
                1319,
                589,
                6780,
                5826,
                7201,
                5325,
                5628,
                3631,
                3752,
                1116,
                4793,
                6931,
                408,
                5808,
                5396,
                4155,
                4739,
                3370,
                2806,
                1263,
                1516,
                2839,
                7138,
                2577,
                5381,
                5881,
                3720,
                1488,
                3989,
                2155,
                4324,
                339,
                3929,
                7498,
                5553,
                21,
                5603,
                4858,
                826,
                3861,
                2048,
                5399,
                1191,
                2451,
                6463,
                2723,
                5631,
                3246,
                5902,
                4669,
                306,
                7809,
                7775,
                761,
                7606,
                4737,
                2860,
                6390,
                4274,
                886,
                4875,
                6915,
                3248,
                4698,
                4710,
                2884,
                943,
                5836,
                5034,
                4454,
                1314,
                2982,
                3572,
                1893,
                1773,
                6884,
                4243,
                5411,
                5217,
                1281,
                2095,
                6163,
                3306,
                5421,
                303,
                5831,
                6377,
                404,
                1913,
                4223,
                2277,
                2658,
                6962,
                5857,
                2715,
                785,
                3871,
                1949,
                6658,
                493,
                3692,
                2668,
                4844,
                2416,
                4565,
                3726,
                3260,
                3202,
                6988,
                6603,
                5364,
                509,
                2211,
                4852,
                7279,
                7037,
                7776,
                157,
                3138,
                4829,
                6366,
                7295,
                5481,
                310,
                5122,
                4763,
                4920,
                1854,
                932,
                4233,
                4551,
                1449,
                3942,
                363,
                872,
                1026,
                6734,
                1794,
                3035,
                5891,
                3336,
                3116,
                289,
                2028,
                2264,
                2870,
                4459,
                5657,
                6125,
                7203,
                5072,
                3811,
                2250,
                3431,
                2836,
                5429,
                1229,
                3133,
                4986,
                3256,
                144,
                3641,
                6170,
                105,
                2442,
                4394,
                2566,
                5376,
                2015,
                819,
                2617,
                2352,
                6643,
                3127,
                4335,
                3583,
                6407,
                2102,
                1636,
                1626,
                990,
                876,
                7098,
                6166,
                6383,
                3799,
                6689,
                423,
                3627,
                4505,
                3440,
                2894,
                1362,
                5939,
                4437,
                5633,
                1753,
                2163,
                4686,
                5513,
                1169,
                1176,
                4611,
                6765,
                5562,
                578,
                1565,
                3716,
                4256,
                5355,
                1207,
                4362,
                6010,
                4932,
                5495,
                5594,
                3791,
                4734,
                6656,
                744,
                3204,
                133,
                1292,
                4306,
                2798,
                1789,
                3747,
                5915,
                1874,
                3462,
                346,
                2701,
                3829,
                2434,
                4636,
                4532,
                7725,
                1945,
                6134,
                3710,
                88,
                14,
                1715,
                1876,
                7066,
                749,
                6286,
                5729,
                2490,
                6895,
                3824,
                430,
                3416,
                2251,
                5237,
                4001,
                4767,
                331,
                2149,
                6149,
                3682,
                3589,
                2501,
                4375,
                488,
                276,
                867,
                3478,
                4677,
                2934,
                1391,
                2016,
                2973,
                5138,
                33,
                4275,
                5108,
                1930,
                2030,
                6819,
                197,
                3636,
                3535,
                3509,
                5683,
                3808,
                3650,
                2853,
                3345,
                7252,
                6727,
                2117,
                5620,
                6897,
                5741,
                4815,
                1790,
                3101,
                3680,
                6544,
                4328,
                1364,
                6703,
                5567,
                6394,
                697,
                6582,
                3018,
                3758,
                7186,
                3063,
                5727,
                2367,
                6228,
                881,
                1255,
                4218,
                17,
                2862,
                69,
                6874,
                6114,
                4092,
                1129,
                868,
                2818,
                3946,
                1469,
                503,
                2559,
                2811,
                1706,
                1133,
                2436,
                2929,
                1494,
                2541,
                6262,
                487,
                5064,
                5656,
                6838,
                2045,
                5319,
                6756,
                5464,
                6405,
                1713,
                6574,
                4610,
                3243,
                2776,
                640,
                5318,
                4833,
                5652,
                4802,
                1935,
                7700,
                7179,
                4496,
                6855,
                6906,
                4152,
                228,
                5463,
                2177,
                118,
                5159,
                4626,
                4735,
                5964,
                1333,
                3443,
                2528,
                6648,
                2430,
                3749,
                5128,
                5144,
                889,
                5539,
                6511,
                3335,
                1453,
                2756,
                2592,
                2597,
                311,
                4285,
                2101,
                3559,
                1674,
                937,
                5617,
                231,
                7699,
                5925,
                3299,
                4350,
                685,
                2781,
                6067,
                4008,
                1803,
                6913,
                6875,
                993,
                4457,
                2011,
                3467,
                369,
                5812,
                3827,
                4444,
                3432,
                5677,
                1234,
                282,
                3962,
                3170,
                1355,
                5980,
                1417,
                5600,
                5019,
                6126,
                2260,
                7031,
                1951,
                236,
                2878,
                5643,
                2406,
                660,
                3828,
                2615,
                5216,
                1833,
                3271,
                7520,
                1572,
                4550,
                2290,
                2196,
                4841,
                6718,
                71,
                2800,
                3366,
                2438,
                5733,
                2760,
                5050,
                3401,
                2025,
                6324,
                1380,
                4422,
                4625,
                4502,
                5401,
                3762,
                378,
                2711,
                1684,
                3668,
                704,
                7182,
                6600,
                3086,
                2042,
                6203,
                4168,
                4797,
                4178,
                7212,
                733,
                4759,
                3792,
                6004,
                4629,
                5547,
                4665,
                4816,
                1848,
                4058,
                3257,
                6497,
                3717,
                2341,
                5871,
                2649,
                223,
                703,
                498,
                2415,
                1265,
                5301,
                1426,
                3950,
                3918,
                367,
                4164,
                3810,
                6346,
                1117,
                4521,
                6334,
                2630,
                2194,
                7044,
                3917,
                5166,
                6494,
                5462,
                4944,
                7403,
                5943,
                3630,
                188,
                3151,
                5431,
                4694,
                2820,
                7630,
                5709,
                5583,
                2898,
                2785,
                76,
                4620,
                1678,
                786,
                1730,
                4014,
                3533,
                2903,
                3725,
                5103,
                5586,
                4225,
                3092,
                1109,
                5654,
                5960,
                4151,
                6654,
                6345,
                1662,
                6123,
                7803,
                4281,
                5258,
                2902,
                6831,
                814,
                393,
                6468,
                3244,
                6945,
                6943,
                1993,
                6458,
                1336,
                4867,
                3400,
                793,
                211,
                580,
                7222,
                265,
                3676,
                131,
                4395,
                5757,
                5953,
                4085,
                6583,
                1617,
                4238,
                1859,
                4894,
                6230,
                5094,
                6105,
                5181,
                5618,
                2532,
                3013,
                5879,
                7678,
                2179,
                6559,
                3139,
                6224,
                4919,
                4387,
                7104,
                6136,
                3321,
                1970,
                3853,
                2428,
                6619,
                752,
                4181,
                812,
                494,
                970,
                6786,
                2816,
                6119,
                263,
                372,
                4105,
                1557,
                1310,
                5021,
                4984,
                3864,
                6393,
                3120,
                4082,
                2567,
                5842,
                3353,
                7317,
                2945,
                5696,
                3673,
                6708,
                3195,
                1500,
                5326,
                5861,
                2370,
                7056,
                6879,
                4110,
                1008,
                2946,
                3947,
                4830,
                229,
                833,
                1190,
                6337,
                4523,
                3656,
                3523,
                1746,
                1136,
                469,
                4971,
                5291,
                4856,
                596,
                5043,
                5877,
                4584,
                5550,
                7333,
                4990,
                1446,
                5649,
                4025,
                2191,
                6990,
                7376,
                3264,
                6862,
                394,
                7599,
                1424,
                2201,
                4091,
                3357,
                4399,
                4642,
                7815,
                1868,
                3216,
                6505,
                6620,
                5781,
                200,
                3694,
                1023,
                6869,
                1535,
                779,
                6106,
                1821,
                2782,
                1585,
                4024,
                7499,
                5543,
                5453,
                1357,
                1460,
                5468,
                1622,
                6043,
                4263,
                5285,
                6963,
                6741,
                3268,
                3887,
                2689,
                6970,
                4687,
                239,
                5705,
                435,
                2890,
                521,
                2586,
                6753,
                1254,
                5109,
                3771,
                5272,
                2914,
                1802,
                4594,
                7140,
                7158,
                46,
                3604,
                2078,
                180,
                3465,
                3355,
                1605,
                5986,
                3266,
                5750,
                1779,
                5612,
                3901,
                4804,
                2420,
                7380,
                2325,
                6525,
                661,
                2213,
                99,
                2491,
                4063,
                1101,
                7159,
                7180,
                6758,
                4199,
                4600,
                3417,
                449,
                971,
                1339,
                5571,
                2376,
                2643,
                1948,
                6036,
                5512,
                4374,
                4649,
                3148,
                1067,
                5590,
                4751,
                6264,
                3421,
                2738,
                4959,
                6532,
                1304,
                1086,
                368,
                1015,
                542,
                1482,
                4832,
                7525,
                5894,
                4381,
                4573,
                2383,
                7048,
                5091,
                1061,
                4906,
                6684,
                1759,
                6686,
                7192,
                7181,
                6098,
                5303,
                4968,
                2237,
                6397,
                4027,
                641,
                1147,
                5774,
                896,
                5363,
                2005,
                3121,
                4766,
                6409,
                5221,
                335,
                5971,
                4390,
                260,
                5658,
                1648,
                1737,
                7105,
                1430,
                4526,
                1393,
                3477,
                5497,
                3003,
                3897,
                278,
                5715,
                2301,
                725,
                1375,
                3577,
                6752,
                1144,
                6113,
                1452,
                5706,
                4617,
                5169,
                1513,
                1163,
                1211,
                5475,
                1726,
                4179,
                6806,
                7214,
                4679,
                5518,
                6660,
                1846,
                5229,
                2849,
                1279,
                1954,
                694,
                5410,
                2663,
                5903,
                385,
                4838,
                4760,
                4782,
                1573,
                6867,
                6109,
                2774,
                1623,
                4613,
                3648,
                6127,
                4479,
                4588,
                2484,
                3846,
                15,
                2947,
                901,
                26,
                4846,
                132,
                4536,
                3576,
                1043,
                6542,
                7477,
                4857,
                6380,
                6749,
                2985,
                4845,
                1587,
                1456,
                6515,
                3839,
                1341,
                3922,
                170,
                4547,
                5545,
                4289,
                2283,
                5317,
                1403,
                5209,
                2334,
                5634,
                5508,
                5204,
                3566,
                5280,
                1044,
                3179,
                3146,
                4294,
                7101,
                1243,
                951,
                1342,
                150,
                2027,
                6520,
                2866,
                2302,
                5844,
                3540,
                297,
                5592,
                6100,
                4922,
                7728,
                3748,
                3554,
                659,
                4874,
                3866,
                2848,
                5247,
                7605,
                4175,
                4954,
                4003,
                2683,
                4992,
                192,
                4286,
                7476,
                3135,
                28,
                3785,
                6063,
                7057,
                2018,
                1273,
                431,
                6275,
                531,
                6626,
                1586,
                3724,
                5791,
                5835,
                2652,
                5907,
                1139,
                204,
                1050,
                4236,
                4276,
                6685,
                3979,
                5097,
                4998,
                1816,
                362,
                7301,
                2736,
                5908,
                695,
                3896,
                2257,
                3363,
                3375,
                5165,
                1478,
                4566,
                5544,
                3796,
                1322,
                4579,
                5860,
                7338,
                5770,
                4811,
                6788,
                6652,
                7773,
                3232,
                5469,
                3142,
                4623,
                6427,
                1311,
                4345,
                857,
                5823,
                2044,
                6479,
                6483,
                141,
                5624,
                6484,
                4704,
                2421,
                508,
                5281,
                3714,
                3241,
                4895,
                2944,
                5105,
                3529,
                2729,
                1955,
                6631,
                1464,
                4142,
                4883,
                3586,
                4941,
                4484,
                2937,
                6877,
                1541,
                3767,
                2568,
                4788,
                3220,
                301,
                7188,
                852,
                1252,
                6562,
                7680,
                245,
                5942,
                877,
                4955,
                1412,
                2664,
                6711,
                3738,
                4004,
                5068,
                1356,
                6435,
                5570,
                4170,
                1498,
                958,
                2024,
                2542,
                2192,
                5756,
                4860,
                6743,
                3418,
                916,
                724,
                6889,
                4590,
                983,
                3205,
                2506,
                5698,
                6922,
                2713,
                5090,
                1080,
                1172,
                1775,
                6772,
                3464,
                5728,
                3314,
                7749,
                361,
                1381,
                1344,
                7807,
                4663,
                1231,
                3590,
                5053,
                77,
                5517,
                4900,
                5779,
                1057,
                2355,
                5175,
                3444,
                4843,
                7724,
                5348,
                6976,
                1030,
                1860,
                4163,
                5972,
                775,
                2670,
                399,
                3169,
                1441,
                5450,
                5988,
                658,
                3775,
                113,
                622,
                257,
                5048,
                3715,
                796,
                6659,
                4146,
                6019,
                2447,
                296,
                853,
                4419,
                3780,
                3480,
                4426,
                5295,
                5311,
                4417,
                5937,
                6623,
                1733,
                3490,
                3068,
                2111,
                7235,
                5931,
                6174,
                4903,
                1084,
                2071,
                6359,
                4654,
                3892,
                2090,
                5046,
                4973,
                1668,
                2832,
                6095,
                7059,
                419,
                7218,
                6735,
                6779,
                3798,
                522,
                5670,
                2841,
                5591,
                7074,
                5542,
                6612,
                5412,
                2077,
                250,
                6665,
                2308,
                5227,
                4633,
                541,
                2410,
                2049,
                4889,
                7088,
                845,
                2847,
                7677,
                4010,
                5385,
                5505,
                2895,
                2940,
                1296,
                4453,
                1665,
                2561,
                4554,
                6518,
                5940,
                22,
                1472,
                7601,
                1717,
                1012,
                4656,
                4529,
                4451,
                1977,
                5133,
                6475,
                3084,
                3449,
                7596,
                3297,
                1160,
                122,
                5900,
                727,
                1326,
                3584,
                6068,
                1017,
                7449,
                7156,
                398,
                2891,
                4964,
                7814,
                72,
                350,
                6299,
                1829,
                5322,
                2380,
                4090,
                1619,
                1840,
                2963,
                681,
                2640,
                2612,
                4043,
                7194,
                3023,
                3304,
                5203,
                5107,
                4032,
                2169,
                2397,
                3180,
                7811,
                977,
                4517,
                760,
                3900,
                2417,
                3328,
                2697,
                675,
                7185,
                1933,
                2393,
                6863,
                3935,
                6712,
                5195,
                5780,
                5852,
                6979,
                4934,
                5201,
                788,
                1661,
                6531,
                1053,
                2401,
                6272,
                7058,
                2705,
                1438,
                1232,
                7681,
                1989,
                3783,
                5946,
                253,
                5667,
                5444,
                2084,
                3697,
                4989,
                6038,
                3740,
                5083,
                784,
                2448,
                2036,
                2123,
                940,
                2717,
                5880,
                2055,
                1523,
                5916,
                4783,
                1965,
                6355,
                4514,
                3294,
                3050,
                2631,
                6112,
                4729,
                910,
                6639,
                5277,
                6164,
                1005,
                3316,
                6257,
                6738,
                2571,
                1040,
                287,
                6687,
                6502,
                5763,
                4945,
                6557,
                3075,
                7425,
                3679,
                468,
                1188,
                1990,
                1287,
                3558,
                2253,
                4477,
                2572,
                3178,
                1533,
                544,
                3407,
                7795,
                7808,
                2457,
                2967,
                2905,
                7169,
                7077,
                7176,
                2394,
                6076,
                4881,
                2977,
                7294,
                5717,
                1979,
                426,
                5752,
                3031,
                3807,
                1776,
                5232,
                2265,
                2175,
                2635,
                7602,
                396,
                7753,
                3390,
                1809,
                953,
                7050,
                2685,
                1122,
                1957,
                1768,
                2351,
                230,
                4360,
                3380,
                6122,
                1289,
                6762,
                4723,
                2508,
                1645,
                7013,
                2063,
                3742,
                4967,
                6062,
                615,
                7283,
                4988,
                6888,
                5436,
                2297,
                7524,
                5638,
                7676,
                610,
                4100,
                1724,
                6069,
                4450,
                5820,
                3403,
                3985,
                5135,
                5929,
                6614,
                2324,
                3300,
                6042,
                3526,
                2248,
                318,
                2831,
                4634,
                4195,
                3079,
                5432,
                5292,
                988,
                3258,
                7001,
                3876,
                1407,
                2835,
                5101,
                1490,
                2625,
                3637,
                7798,
                3606,
                566,
                5822,
                7200,
                6503,
                7378,
                5672,
                4601,
                456,
                3132,
                3520,
                3945,
                6696,
                6385,
                584,
                2118,
                715,
                2886,
                1299,
                1714,
                1447,
                4266,
                4429,
                6160,
                6215,
                6002,
                1233,
                161,
                286,
                5918,
                3961,
                145,
                1320,
                7428,
                7255,
                87,
                1507,
                2313,
                272,
                6885,
                6912,
                838,
                6680,
                2659,
                1799,
                171,
                4994,
                5202,
                6790,
                5187,
                94,
                3875,
                4476,
                5393,
                175,
                432,
                4748,
                7091,
                174,
                5955,
                292,
                3904,
                4158,
                2115,
                5474,
                5086,
                187,
                3999,
                2679,
                4693,
                5610,
                6657,
                4414,
                3782,
                89,
                6231,
                5264,
                903,
                7627,
                790,
                7604,
                6551,
                5888,
                24,
                2857,
                4985,
                4356,
                1635,
                529,
                6082,
                142,
                4252,
                2855,
                6158,
                3078,
                4784,
                673,
                3580,
                1134,
                720,
                2400,
                2665,
                519,
                474,
                2755,
                6807,
                7501,
                3751,
                5158,
                5858,
                7549,
                6716,
                1900,
                2604,
                4468,
                4258,
                1249,
                2336,
                780,
                6674,
                2054,
                2243,
                5650,
                636,
                3855,
                7450,
                5565,
                6097,
                2889,
                3128,
                8,
                7652,
                5430,
                2725,
                2424,
                3047,
                5523,
                6571,
                1293,
                632,
                7260,
                602,
                6810,
                1720,
                908,
                6187,
                6832,
                4354,
                3457,
                3582,
                3290,
                5151,
                5186,
                450,
                123,
                3379,
                482,
                70,
                3560,
                1729,
                6608,
                3016,
                5957,
                371,
                7115,
                6311,
                63,
                436,
                2217,
                6729,
                1738,
                6412,
                6265,
                3211,
                4115,
                637,
                5125,
                2076,
                1076,
                7570,
                4070,
                6802,
                6060,
                4552,
                1512,
                6250,
                3937,
                1157,
                1081,
                4504,
                1694,
                1312,
                6745,
                6796,
                1695,
                549,
                2846,
                5742,
                7213,
                209,
                5079,
                117,
                5500,
                4023,
                6577,
                7100,
                5557,
                6444,
                179,
                321,
                4890,
                1649,
                5702,
                2259,
                5316,
                5174,
                3034,
                2962,
                5814,
                5006,
                3007,
                3849,
                526,
                5837,
                864,
                587,
                1267,
                218,
                453,
                1604,
                550,
                1891,
                6431,
                5309,
                5609,
                590,
                554,
                984,
                1445,
                5575,
                6336,
                3677,
                165,
                3869,
                6675,
                2704,
                1673,
                5002,
                4140,
                5390,
                162,
                4224,
                6815,
                2317,
                4814,
                6347,
                3076,
                4696,
                3274,
                4500,
                1097,
                5664,
                656,
                6487,
                5115,
                463,
                66,
                6292,
                6751,
                4272,
                1082,
                6541,
                5538,
                5873,
                3831,
                6425,
                5370,
                2609,
                3060,
                5825,
                2722,
                5492,
                6719,
                7447,
                1520,
                4818,
                5012,
                4448,
                3099,
                2235,
                5155,
                106,
                7239,
                3349,
                1220,
                6512,
                120,
                3203,
                4391,
                4773,
                6276,
                7774,
                6830,
                3356,
                6949,
                2089,
                973,
                4474,
                7405,
                6028,
                3647,
                6096,
                4854,
                2167,
                2073,
                3562,
                5307,
                6936,
                3109,
                4574,
                6661,
                709,
                4337,
                4214,
                4120,
                3683,
                1105,
                5926,
                5035,
                4749,
                1558,
                4872,
                4088,
                5063,
                7497,
                5330,
                1624,
                2952,
                5483,
                195,
                1455,
                3730,
                3414,
                3800,
                7086,
                2,
                6818,
                5958,
                2666,
                1238,
                2094,
                5593,
                2441,
                137,
                7004,
                3690,
                4624,
                2112,
                6586,
                6052,
                818,
                1612,
                6841,
                6118,
                739,
                3411,
                1761,
                6133,
                6399,
                4976,
                1465,
                5821,
                4473,
                4923,
                5904,
                3238,
                57,
                4071,
                2052,
                495,
                556,
                5,
                3729,
                6792,
                6274,
                1543,
                711,
                1830,
                6938,
                6327,
                1920,
                854,
                729,
                6440,
                7234,
                6404,
                5708,
                5830,
                4352,
                6896,
                830,
                4557,
                2241,
                7096,
                1098,
                3237,
                7040,
                6013,
                1719,
                1625,
                115,
                2186,
                2579,
                3277,
                4204,
                5038,
                262,
                6017,
                2623,
                5690,
                1655,
                5659,
                629,
                1009,
                1202,
                7269,
                2053,
                6955,
                5994,
                7571,
                2498,
                3209,
                2362,
                359,
                4716,
                5846,
                635,
                975,
                1022,
                4423,
                543,
                5788,
                1632,
                6691,
                1033,
                2512,
                6668,
                128,
                3666,
                4798,
                7424,
                2584,
                3870,
                3499,
                2304,
                5344,
                3550,
                2220,
                6418,
                2858,
                2291,
                2502,
                3519,
                344,
                848,
                5660,
                652,
                6789,
                3212,
                700,
                5783,
                7401,
                6301,
                6234,
                6015,
                2419,
                6185,
                4302,
                1698,
                3189,
                447,
                7099,
                3913,
                6953,
                2269,
                3502,
                4205,
                2956,
                1808,
                2981,
                922,
                6205,
                5416,
                1683,
                3342,
                827,
                4470,
                7241,
                7170,
                6969,
                6077,
                1897,
                3610,
                905,
                712,
                7232,
                545,
                2997,
                3825,
                2384,
                7246,
                6791,
                612,
                5707,
                6306,
                5030,
                1764,
                7270,
                3042,
                5602,
                1216,
                2580,
                3234,
                1922,
                607,
                341,
                2636,
                7225,
                4279,
                489,
                7453,
                4576,
                890,
                5345,
                6864,
                3136,
                2437,
                3928,
                4044,
                2728,
                6917,
                525,
                5932,
                3309,
                7046,
                3037,
                6667,
                1818,
                5270,
                6219,
                5984,
                3263,
                7130,
                3804,
                6981,
                4947,
                3482,
                4344,
                5679,
                1865,
                3669,
                1077,
                4631,
                4810,
                2455,
                7300,
                5910,
                6798,
                2788,
                2644,
                442,
                1440,
                2686,
                4370,
                2645,
                3168,
                6695,
                5031,
                1475,
                59,
                1976,
                2746,
                1745,
                6744,
                7572,
                504,
                2479,
                5815,
                5044,
                5486,
                747,
                1546,
                2842,
                5997,
                6014,
                5767,
                6453,
                6217,
                2409,
                6605,
                2463,
                1410,
                6524,
                7675,
                4083,
                61,
                4727,
                3398,
                4211,
                2606,
                1774,
                1607,
                5092,
                3157,
                5077,
                3051,
                3813,
                923,
                6420,
                1548,
                6457,
                4494,
                1595,
                7371,
                3410,
                252,
                1906,
                5850,
                5111,
                7274,
                5384,
                534,
                574,
                1389,
                1108,
                4618,
                935,
                4413,
                7259,
                4125,
                4717,
                5114,
                1510,
                6429,
                6120,
                2754,
                2261,
                3352,
                1727,
                6401,
                4208,
                3968,
                5587,
                2709,
                6837,
                2140,
                5346,
                427,
                6693,
                1413,
                5013,
                227,
                4702,
                722,
                2399,
                1016,
                1282,
                2712,
                5798,
                5042,
                1165,
                6033,
                1807,
                1372,
                154,
                7368,
                38,
                2930,
                2459,
                5332,
                568,
                1671,
                707,
                2339,
                3633,
                4095,
                6683,
                4013,
                6073,
                6124,
                1653,
                5057,
                3654,
                1828,
                6849,
                3025,
                177,
                1524,
                3145,
                2530,
                4177,
                5085,
                5438,
                2081,
                7314,
                7657,
                2693,
                1170,
                2134,
                3786,
                6233,
                2880,
                7161,
                182,
                4898,
                4722,
                1006,
                3064,
                5466,
                1771,
                5995,
                1028,
                4084,
                1432,
                2646,
                5811,
                1997,
                4124,
                7521,
                4996,
                3229,
                5223,
                3012,
                129,
                6803,
                7236,
                307,
                5637,
                2989,
                2378,
                6145,
                5273,
                6190,
                7005,
                5313,
                4539,
                3252,
                5081,
                2823,
                1800,
                2861,
                4447,
                5520,
                5622,
                5498,
                2059,
                1567,
                3347,
                5897,
                1132,
                4706,
                5302,
                2661,
                5853,
                1406,
                4530,
                2246,
                6191,
                5171,
                4041,
                5987,
                1471,
                5674,
                4963,
                517,
                3709,
                397,
                947,
                2699,
                3115,
                3522,
                3852,
                4848,
                3021,
                823,
                4180,
                20,
                2333,
                3818,
                1150,
                735,
                6971,
                6251,
                6682,
                7812,
                2369,
                93,
                2122,
                3186,
                5577,
                5772,
                5818,
                2310,
                2747,
                5669,
                2203,
                1815,
                3593,
                6774,
                5680,
                3642,
                4439,
                2143,
                963,
                6213,
                111,
                414,
                6090,
                995,
                4776,
                6777,
                4061,
                7055,
                3977,
                2553,
                686,
                2172,
                6646,
                244,
                5075,
                5506,
                870,
                7009,
                3658,
                4743,
                3488,
                6221,
                1610,
                895,
                3454,
                6259,
                3731,
                1128,
                5392,
                677,
                1159,
                5641,
                1539,
                5420,
                976,
                6352,
                1919,
                37,
                2252,
                3757,
                5859,
                4201,
                98,
                1647,
                4738,
                6540,
                2189,
                4173,
                3988,
                74,
                3998,
                6568,
                196,
                1716,
                441,
                1386,
                6322,
                6728,
                29,
                1206,
                3378,
                3164,
                5140,
                5924,
                4015,
                10,
                2158,
                6887,
                5352,
                4313,
                1950,
                4144,
                2425,
                3492,
                4787,
                7129,
                4026,
                809,
                5713,
                299,
                5878,
                2206,
                5711,
                6550,
                4901,
                2375,
                7603,
                5928,
                2608,
                6141,
                3652,
                3315,
                7429,
                7280,
                275,
                1511,
                1824,
                305,
                2295,
                2262,
                2350,
                691,
                7095,
                6704,
                3020,
                2610,
                6545,
                2999,
                2844,
                567,
                3126,
                1045,
                3921,
                220,
                1491,
                173,
                1253,
                1772,
                6844,
                2920,
                3881,
                2802,
                4792,
                799,
                3518,
                3038,
                6843,
                2596,
                6144,
                2452,
                1174,
                1961,
                3360,
                1088,
                797,
                6074,
                2768,
                2318,
                836,
                5045,
                1295,
                4340,
                624,
                3865,
                3879,
                5731,
                2300,
                6998,
                4339,
                1171,
                5967,
                143,
                6805,
                4129,
                3190,
                627,
                5383,
                4134,
                7335,
                4349,
                5993,
                1085,
                4891,
                4828,
                3156,
                1892,
                1862,
                7131,
                7271,
                7806,
                6313,
                6137,
                207,
                2748,
                6152,
                4958,
                5769,
                5467,
                5613,
                3338,
                1872,
                5357,
                6376,
                4117,
                1538,
                4323,
                6578,
                4537,
                4908,
                1590,
                736,
                4641,
                5354,
                6785,
                2481,
                5010
        #endregion  Recipe IDList
            };

        public static IdList ItemIdListExpected = new IdList
            {
                12546,
                38875,
                26706,
                28445,
                34460,
                26920,
                29051,
                12079,
                2404
            };

        public static List<GuildDetailsEntry> GuildDetailsExpected = new List<GuildDetailsEntry>
            {
                new GuildDetailsEntry
                    {
                        GuildId = new Guid("E27EB3AA-EAFA-4C1B-BA7A-5202A519E291"),
                        GuildName = "Valour Of The Forsaken",
                        Tag = "VOTF",
                        Emblem = new GuildDetailsEntry.EmblemProperties
                            {
                                BackgroundId = 23,
                                ForegroundId = 70,
                                Flags = new string[0],
                                BackgroundColorId = 443,
                                ForegroundPrimaryColorId = 584,
                                ForegroundSecondaryColorId = 473,
                            },

                    },
            };

        public static List<RecipeDetailsEntry> RecipeDetailsExpected = new List<RecipeDetailsEntry>
            {
                new RecipeDetailsEntry
                    {
                        RecipeId = 1275,
                        RecipeType = RecipeType.Coat,
                        OutputItemId = 11541,
                        OutputCount = 1,
                        MinRating = 25,
                        TimeToCraftMsec = 1000,
                        Diciplines = new[]
                            {
                                DisciplineType.Leatherworker,
                            },
                        Flags = new string[0],
                        Ingredients = new EntryCollection<RecipeIngredient>
                            {
                                new RecipeIngredient
                                    {
                                        ItemId = 19797,
                                        Count = 1,
                                    },
                                new RecipeIngredient
                                    {
                                        ItemId = 13094,
                                        Count = 1,
                                    },
                                new RecipeIngredient
                                    {
                                        ItemId = 13093,
                                        Count = 1,
                                    },
                            },
                    }
            };

        public static List<ItemDetailsEntry> ItemDetailsExpected = new List<ItemDetailsEntry>
            {
                new ItemDetailsEntry
                    {
                        ItemId = 12862,
                        Name = "Iron Hammer Head",
                        Description = "Used to craft Hammers.",
                        ItemType = ItemType.CraftingMaterial,
                        Level = 0,
                        Rarity = RarityType.Basic,
                        VendorValue = 4,
                        IconFileId = 63414,
                        IconFileSignature = "EB1C07BCE542B95CD6A2CB4E4D06AF5EA0E678DD",
                        GameType = new[] {GameType.Activity, GameType.Dungeon, GameType.PvE, GameType.WvW},
                        Flags = new string[0],
                        Restrictions = new string[0],
                    }
            };

        public static EntryCollection<EventEntry> EventEntriesExpected = new EntryCollection<EventEntry>
            {
                new EventEntry()
                    {
                        WorldId = 1017,
                        MapId = 50,
                        EventId = new Guid("BAD81BA0-60CF-4F3B-A341-57C426085D48"),
                        State = EventState.Active,
                    },
                new EventEntry()
                    {
                        WorldId = 1017,
                        MapId = 50,
                        EventId = new Guid("330BE72A-5254-4036-ACB6-7AEED05A521C"),
                        State = EventState.Active,
                    },
                new EventEntry()
                    {
                        WorldId = 2011,
                        MapId = 873,
                        EventId = new Guid("B13EA882-065D-470A-8A9D-10A395373C68"),
                        State = EventState.Warmup,
                    },
            };


        public static EntryDictionary<string, FileEntry> FileEntriesExpected = new EntryDictionary<string, FileEntry>
            {
                {
                    "map_complete",
                    new FileEntry
                        {
                            FileID = 528724,
                            Signature = "5A4E663071250EC72668C09E3C082E595A380BF7"
                        }
                },
                {
                    "map_dungeon",
                    new FileEntry
                        {
                            FileID = 102478,
                            Signature = "943538394A94A491C8632FBEF6203C2013443555"
                        }
                },
                {
                    "map_heart_empty",
                    new FileEntry
                        {
                            FileID = 102440,
                            Signature = "09ACBA53B7412CC3C76E7FEF39929843C20CB0E4"
                        }
                },
                {
                    "map_heart_full",
                    new FileEntry
                        {
                            FileID = 102439,
                            Signature = "B3DEEC72BBEF0C6FC6FEF835A0E275FCB1151BB7"
                        }
                },
                {
                    "map_node_harvesting",
                    new FileEntry
                        {
                            FileID = 157332,
                            Signature = "995534EBE5D26804AE605E205E50539821C0CBCB"
                        }
                },
                {
                    "map_node_logging",
                    new FileEntry
                        {
                            FileID = 157333,
                            Signature = "FC01BB452D5327A0E5B2E4A3F5EFDF03F8264A7B"
                        }
                },
                {
                    "map_node_mining",
                    new FileEntry
                        {
                            FileID = 157334,
                            Signature = "A89EB66C39C7C006A4A6CBEDA28061F16847E9BC"
                        }
                },
                {
                    "map_poi",
                    new FileEntry
                        {
                            FileID = 97461,
                            Signature = "25B230711176AB5728E86F5FC5F0BFAE48B32F6E"
                        }
                },
                {
                    "map_special_event",
                    new FileEntry
                        {
                            FileID = 502087,
                            Signature = "1273C427032320DDDB63062C140E72DCB0D9B411"
                        }
                },
                {
                    "map_story",
                    new FileEntry
                        {
                            FileID = 102369,
                            Signature = "540BA9BB6662A5154BD13306A1AEAD6219F95361"
                        }
                },
                {
                    "map_waypoint",
                    new FileEntry
                        {
                            FileID = 157353,
                            Signature = "32633AF8ADEA696A1EF56D3AE32D617B10D3AC57"
                        }
                },
                {
                    "map_waypoint_contested",
                    new FileEntry
                        {
                            FileID = 102349,
                            Signature = "5EF051273B40CFAC4AEA6C1F1D0DA612C1B0776C"
                        }
                },
                {
                    "map_waypoint_hover",
                    new FileEntry
                        {
                            FileID = 157354,
                            Signature = "95CE3F6B0502232AD90034E4B7CE6E5B0FD3CC5F"
                        }
                }
            };

        #endregion Expected Values
    }
}
